@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,8 @@
  */
 package net.sourceforge.plantuml;
 
-import java.awt.geom.Dimension2D;
+import java.awt.Dimension;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 
 import net.sourceforge.plantuml.utils.MathUtils;
@@ -135,4 +136,8 @@ public class Dimension2DDouble extends Dimension2D {
 		return new Dimension2DDouble(w, h);
 	}
 
+	public static Dimension2D fromDimension(Dimension dimension) {
+		return new Dimension2D(dimension.getWidth(), dimension.getHeight());
+	}
+
 }
