@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -38,6 +38,8 @@ package net.sourceforge.plantuml;
 import java.awt.Font;
 
 import net.sourceforge.plantuml.graphic.FontConfiguration;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
 
 interface FontParamConstant {
 	String FAMILY = "SansSerif";
@@ -45,6 +47,7 @@ interface FontParamConstant {
 }
 
 public enum FontParam {
+	TIMING(12, Font.PLAIN), //
 	ACTIVITY(12, Font.PLAIN), //
 	ACTIVITY_DIAMOND(11, Font.PLAIN), //
 	// ACTIVITY_ARROW(11, Font.PLAIN), //
@@ -76,6 +79,10 @@ public enum FontParam {
 	ENTITY(14, Font.PLAIN), //
 	AGENT(14, Font.PLAIN), //
 	RECTANGLE(14, Font.PLAIN), //
+	LABEL(14, Font.PLAIN), //
+	HEXAGON(14, Font.PLAIN), //
+	PERSON(14, Font.PLAIN), //
+	ARCHIMATE(14, Font.PLAIN), //
 	CARD(14, Font.PLAIN), //
 	NODE(14, Font.PLAIN), //
 	DATABASE(14, Font.PLAIN), //
@@ -89,11 +96,12 @@ public enum FontParam {
 	SEQUENCE_GROUP(11, Font.BOLD), //
 	SEQUENCE_GROUP_HEADER(13, Font.BOLD), //
 	PARTICIPANT(14, Font.PLAIN), //
-	SEQUENCE_TITLE(14, Font.BOLD), //
+	PARTICIPANT_STEREOTYPE(14, Font.ITALIC), //
 	STATE(14, Font.PLAIN), //
 	STATE_ATTRIBUTE(12, Font.PLAIN), //
 	LEGEND(14, Font.PLAIN), //
 	TITLE(18, Font.PLAIN), //
+	// SEQUENCE_TITLE(14, Font.BOLD), //
 	CAPTION(14, Font.PLAIN), //
 	SWIMLANE_TITLE(18, Font.PLAIN), //
 	FOOTER(10, Font.PLAIN, "#888888", FontParamConstant.FAMILY), //
@@ -108,6 +116,10 @@ public enum FontParam {
 	ENTITY_STEREOTYPE(14, Font.ITALIC), //
 	AGENT_STEREOTYPE(14, Font.ITALIC), //
 	RECTANGLE_STEREOTYPE(14, Font.ITALIC), //
+	LABEL_STEREOTYPE(14, Font.ITALIC), //
+	PERSON_STEREOTYPE(14, Font.ITALIC), //
+	HEXAGON_STEREOTYPE(14, Font.ITALIC), //
+	ARCHIMATE_STEREOTYPE(14, Font.ITALIC), //
 	CARD_STEREOTYPE(14, Font.ITALIC), //
 	NODE_STEREOTYPE(14, Font.ITALIC), //
 	FOLDER_STEREOTYPE(14, Font.ITALIC), //
@@ -118,8 +130,7 @@ public enum FontParam {
 	STACK_STEREOTYPE(14, Font.ITALIC), //
 	ACTOR_STEREOTYPE(14, Font.ITALIC), //
 	SEQUENCE_STEREOTYPE(14, Font.ITALIC), //
-	PARTITION(14, Font.PLAIN),
-	DESIGNED_DOMAIN(12, Font.PLAIN), //
+	PARTITION(14, Font.PLAIN), DESIGNED_DOMAIN(12, Font.PLAIN), //
 	DESIGNED_DOMAIN_STEREOTYPE(12, Font.ITALIC), //
 	DOMAIN(12, Font.PLAIN), //
 	DOMAIN_STEREOTYPE(12, Font.ITALIC), //
@@ -176,4 +187,25 @@ public enum FontParam {
 		return new FontConfiguration(skinParam, this, null);
 	}
 
+	public StyleSignatureBasic getStyleDefinition(SName diagramType) {
+		if (this == FOOTER) {
+			return StyleSignatureBasic.of(SName.root, SName.document, SName.footer);
+		}
+		if (this == HEADER) {
+			return StyleSignatureBasic.of(SName.root, SName.document, SName.header);
+		}
+		if (this == TITLE) {
+			return StyleSignatureBasic.of(SName.root, SName.document, SName.title);
+		}
+		if (this == CLASS_ATTRIBUTE) {
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.classDiagram, SName.class_);
+		}
+		if (this == RECTANGLE || this == NODE) {
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.componentDiagram, SName.component);
+		}
+		return StyleSignatureBasic.of(SName.root, SName.element, diagramType, SName.component);
+//		System.err.println("Warning " + this);
+//		throw new UnsupportedOperationException();
+	}
+
 }
