@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,6 +35,8 @@
  */
 package net.sourceforge.plantuml;
 
+import java.util.Objects;
+
 public class LineLocationImpl implements LineLocation {
 
 	private final String desc;
@@ -51,11 +53,8 @@ public class LineLocationImpl implements LineLocation {
 	}
 
 	private LineLocationImpl(String desc, LineLocation parent, int position) {
-		if (desc == null) {
-			throw new IllegalArgumentException();
-		}
 		this.parent = parent;
-		this.desc = desc;
+		this.desc = Objects.requireNonNull(desc);
 		this.position = position;
 	}
 
@@ -63,13 +62,6 @@ public class LineLocationImpl implements LineLocation {
 		return new LineLocationImpl(desc, parent, position + 1);
 	}
 
-	public static LineLocation fromLine(CharSequence cs) {
-		if (cs instanceof CharSequence2) {
-			return ((CharSequence2) cs).getLocation();
-		}
-		return null;
-	}
-
 	public int getPosition() {
 		return position;
 	}
@@ -82,8 +74,18 @@ public class LineLocationImpl implements LineLocation {
 		return parent;
 	}
 
+	private boolean isStandardLibrary() {
+		return desc.startsWith("<");
+	}
+
 	public int compareTo(LineLocation other) {
 		final LineLocationImpl other2 = (LineLocationImpl) other;
+		if (this.isStandardLibrary() && other2.isStandardLibrary() == false) {
+			return -1;
+		}
+		if (this.isStandardLibrary() == false && other2.isStandardLibrary()) {
+			return 1;
+		}
 		return this.position - other2.position;
 	}
 
