@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,12 +35,15 @@
  */
 package net.sourceforge.plantuml;
 
-import net.sourceforge.plantuml.ugraphic.sprite.Sprite;
+import net.sourceforge.plantuml.api.ThemeStyle;
+import net.sourceforge.plantuml.sprite.Sprite;
 
-public interface SpriteContainer {
+public interface SpriteContainer extends SvgCharSizeHack {
 
 	public Sprite getSprite(String name);
 
-	public boolean useGuillemet();
+	public Guillemet guillemet();
+	
+	public ThemeStyle getThemeStyle();
 
 }
\ No newline at end of file
