@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -41,6 +41,7 @@ import java.util.List;
 import java.util.Map;
 
 import ext.plantuml.com.ctreber.acearth.plugins.markers.Marker;
+import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.command.PSystemBasicFactory;
 import net.sourceforge.plantuml.command.regex.Matcher2;
 import net.sourceforge.plantuml.command.regex.MyPattern;
@@ -55,7 +56,7 @@ public class PSystemXearthFactory extends PSystemBasicFactory<PSystemXearth> {
 	private int height;
 
 	@Override
-	public PSystemXearth initDiagram(UmlSource source, String startLine) {
+	public PSystemXearth initDiagram(ThemeStyle style, UmlSource source, String startLine) {
 		this.width = 512;
 		this.height = 512;
 		this.config.clear();
@@ -74,18 +75,18 @@ public class PSystemXearthFactory extends PSystemBasicFactory<PSystemXearth> {
 	}
 
 	@Override
-	public PSystemXearth executeLine(UmlSource source, PSystemXearth system, String line) {
+	public PSystemXearth executeLine(ThemeStyle style, UmlSource source, PSystemXearth system, String line) {
 		if (system == null && line.startsWith("xearth")) {
 			extractDimension(line);
 			system = new PSystemXearth(source, width, height, config, markers);
 			return system;
 		}
-		if (system == null) {
+		if (system == null)
 			return null;
-		}
-		if (line.startsWith("#") || line.startsWith("'")) {
+
+		if (line.startsWith("#") || line.startsWith("'"))
 			return system;
-		}
+
 		final Pattern2 p = MyPattern.cmpile("(\\w+)[%s]*=[%s]*(.*)");
 		final Matcher2 m = p.matcher(line);
 		if (m.find()) {
