@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -37,10 +37,12 @@ package net.sourceforge.plantuml.activitydiagram3.ftile;
 
 import java.util.Collection;
 import java.util.List;
+import java.util.Objects;
 
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.Url;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.activitydiagram3.Branch;
 import net.sourceforge.plantuml.activitydiagram3.ForkStyle;
 import net.sourceforge.plantuml.activitydiagram3.Instruction;
@@ -48,15 +50,19 @@ import net.sourceforge.plantuml.activitydiagram3.LinkRendering;
 import net.sourceforge.plantuml.activitydiagram3.PositionedNote;
 import net.sourceforge.plantuml.creole.CreoleMode;
 import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.HtmlColor;
-import net.sourceforge.plantuml.graphic.HtmlColorAndStyle;
 import net.sourceforge.plantuml.graphic.Rainbow;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
+import net.sourceforge.plantuml.graphic.USymbol;
 import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class FtileFactoryDelegator implements FtileFactory {
 
@@ -64,16 +70,40 @@ public class FtileFactoryDelegator implements FtileFactory {
 
 	private final Rose rose = new Rose();
 
+	final public StyleSignatureBasic getDefaultStyleDefinitionActivity() {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.activity);
+	}
+
+	final public StyleSignatureBasic getDefaultStyleDefinitionDiamond() {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.activity, SName.diamond);
+	}
+
+	final public StyleSignatureBasic getDefaultStyleDefinitionArrow() {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.arrow);
+	}
+
 	protected final Rainbow getInLinkRenderingColor(Ftile tile) {
 		Rainbow color;
 		final LinkRendering linkRendering = tile.getInLinkRendering();
 		if (linkRendering == null) {
-			color = HtmlColorAndStyle.build(skinParam());
+			if (UseStyle.useBetaStyle()) {
+				final Style style = getDefaultStyleDefinitionArrow()
+						.getMergedStyle(skinParam().getCurrentStyleBuilder());
+				return Rainbow.build(style, skinParam().getIHtmlColorSet(), skinParam().getThemeStyle());
+			} else {
+				color = Rainbow.build(skinParam());
+			}
 		} else {
 			color = linkRendering.getRainbow();
 		}
 		if (color.size() == 0) {
-			color = HtmlColorAndStyle.build(skinParam());
+			if (UseStyle.useBetaStyle()) {
+				final Style style = getDefaultStyleDefinitionArrow()
+						.getMergedStyle(skinParam().getCurrentStyleBuilder());
+				return Rainbow.build(style, skinParam().getIHtmlColorSet(), skinParam().getThemeStyle());
+			} else {
+				color = Rainbow.build(skinParam());
+			}
 		}
 		return color;
 	}
@@ -83,8 +113,14 @@ public class FtileFactoryDelegator implements FtileFactory {
 		if (Display.isNull(display)) {
 			return null;
 		}
-		final FontConfiguration fontConfiguration = new FontConfiguration(skinParam(), FontParam.ARROW, null);
-		return display.create(fontConfiguration, HorizontalAlignment.LEFT, skinParam(), CreoleMode.SIMPLE_LINE);
+		final FontConfiguration fontConfiguration;
+		if (UseStyle.useBetaStyle()) {
+			final Style style = getDefaultStyleDefinitionArrow().getMergedStyle(skinParam().getCurrentStyleBuilder());
+			fontConfiguration = style.getFontConfiguration(skinParam().getThemeStyle(), skinParam().getIHtmlColorSet());
+		} else {
+			fontConfiguration = new FontConfiguration(skinParam(), FontParam.ARROW, null);
+		}
+		return display.create7(fontConfiguration, HorizontalAlignment.LEFT, skinParam(), CreoleMode.SIMPLE_LINE);
 	}
 
 	protected Display getInLinkRenderingDisplay(Ftile tile) {
@@ -111,12 +147,12 @@ public class FtileFactoryDelegator implements FtileFactory {
 		return factory.stop(swimlane);
 	}
 
-	public Ftile spot(Swimlane swimlane, String spot) {
-		return factory.spot(swimlane, spot);
+	public Ftile spot(Swimlane swimlane, String spot, HColor color) {
+		return factory.spot(swimlane, spot, color);
 	}
 
-	public Ftile activity(Display label, Swimlane swimlane, BoxStyle style, Colors colors) {
-		return factory.activity(label, swimlane, style, colors);
+	public Ftile activity(Display label, Swimlane swimlane, BoxStyle style, Colors colors, Stereotype stereotype) {
+		return factory.activity(label, swimlane, style, colors, stereotype);
 	}
 
 	public Ftile addNote(Ftile ftile, Swimlane swimlane, Collection<PositionedNote> notes) {
@@ -128,47 +164,47 @@ public class FtileFactoryDelegator implements FtileFactory {
 	}
 
 	public Ftile decorateIn(Ftile ftile, LinkRendering linkRendering) {
-		if (linkRendering == null) {
-			throw new IllegalArgumentException();
-		}
-		return factory.decorateIn(ftile, linkRendering);
+		return factory.decorateIn(ftile, Objects.requireNonNull(linkRendering));
 	}
 
 	public Ftile decorateOut(Ftile ftile, LinkRendering linkRendering) {
-		if (linkRendering == null) {
-			throw new IllegalArgumentException();
-		}
-		return factory.decorateOut(ftile, linkRendering);
+		return factory.decorateOut(ftile, Objects.requireNonNull(linkRendering));
 	}
 
 	public Ftile assembly(Ftile tile1, Ftile tile2) {
 		return factory.assembly(tile1, tile2);
 	}
 
-	public Ftile repeat(Swimlane swimlane, Swimlane swimlaneOut, Display startLabel, Ftile repeat, Display test,
-			Display yes, Display out, HtmlColor color, LinkRendering backRepeatLinkRendering, Ftile backward,
-			boolean noOut) {
-		return factory.repeat(swimlane, swimlaneOut, startLabel, repeat, test, yes, out, color,
-				backRepeatLinkRendering, backward, noOut);
+	public Ftile repeat(BoxStyle boxStyleIn, Swimlane swimlane, Swimlane swimlaneOut, Display startLabel, Ftile repeat,
+			Display test, Display yes, Display out, Colors colors, Ftile backward, boolean noOut,
+			LinkRendering incoming1, LinkRendering incoming2) {
+		return factory.repeat(boxStyleIn, swimlane, swimlaneOut, startLabel, repeat, test, yes, out, colors, backward,
+				noOut, incoming1, incoming2);
 	}
 
-	public Ftile createWhile(Swimlane swimlane, Ftile whileBlock, Display test, Display yes, Display out,
-			LinkRendering afterEndwhile, HtmlColor color, Instruction specialOut) {
-		return factory.createWhile(swimlane, whileBlock, test, yes, out, afterEndwhile, color, specialOut);
+	public Ftile createWhile(LinkRendering outColor, Swimlane swimlane, Ftile whileBlock, Display test, Display yes,
+			HColor color, Instruction specialOut, Ftile back, LinkRendering incoming1, LinkRendering incoming2) {
+		return factory.createWhile(outColor, swimlane, whileBlock, test, yes, color, specialOut, back, incoming1,
+				incoming2);
 	}
 
 	public Ftile createIf(Swimlane swimlane, List<Branch> thens, Branch elseBranch, LinkRendering afterEndwhile,
-			LinkRendering topInlinkRendering) {
-		return factory.createIf(swimlane, thens, elseBranch, afterEndwhile, topInlinkRendering);
+			LinkRendering topInlinkRendering, Url url) {
+		return factory.createIf(swimlane, thens, elseBranch, afterEndwhile, topInlinkRendering, url);
 	}
 
-	public Ftile createParallel(Swimlane swimlane, List<Ftile> all, ForkStyle style, String label) {
-		return factory.createParallel(swimlane, all, style, label);
+	public Ftile createSwitch(Swimlane swimlane, List<Branch> branches, LinkRendering afterEndwhile,
+			LinkRendering topInlinkRendering, Display labelTest) {
+		return factory.createSwitch(swimlane, branches, afterEndwhile, topInlinkRendering, labelTest);
 	}
 
-	public Ftile createGroup(Ftile list, Display name, HtmlColor backColor, HtmlColor titleColor, PositionedNote note,
-			HtmlColor borderColor) {
-		return factory.createGroup(list, name, backColor, titleColor, note, borderColor);
+	public Ftile createParallel(List<Ftile> all, ForkStyle style, String label, Swimlane in, Swimlane out) {
+		return factory.createParallel(all, style, label, in, out);
+	}
+
+	public Ftile createGroup(Ftile list, Display name, HColor backColor, HColor titleColor, PositionedNote note,
+			HColor borderColor, USymbol type, double roundCorner) {
+		return factory.createGroup(list, name, backColor, titleColor, note, borderColor, type, roundCorner);
 	}
 
 	public StringBounder getStringBounder() {
