@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.ftile.vcompact;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.util.Collection;
 import java.util.Set;
 
@@ -62,7 +62,7 @@ import net.sourceforge.plantuml.graphic.USymbol;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.style.StyleSignature;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.UGraphicForSnake;
 import net.sourceforge.plantuml.ugraphic.LimitFinder;
 import net.sourceforge.plantuml.ugraphic.MinMax;
@@ -87,8 +87,8 @@ public class FtileGroup extends AbstractFtile {
 	private final USymbol type;
 	private final double roundCorner;
 
-	final public StyleSignature getDefaultStyleDefinitionPartition() {
-		return StyleSignature.of(SName.root, SName.element, SName.activityDiagram, SName.partition);
+	final public StyleSignatureBasic getStyleSignature() {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.partition);
 	}
 
 	public FtileGroup(Ftile inner, Display title, Display displayNote, HColor arrowColor, HColor backColor,
@@ -96,36 +96,43 @@ public class FtileGroup extends AbstractFtile {
 		super(inner.skinParam());
 		this.roundCorner = roundCorner;
 		this.type = type;
-		this.backColor = backColor == null ? HColorUtils.WHITE : backColor;
 		this.inner = FtileUtils.addHorizontalMargin(inner, 10);
-		this.borderColor = borderColor == null ? HColorUtils.BLACK : borderColor;
 
 		final FontConfiguration fc;
 		final Style style;
+		final UStroke thickness;
 		if (UseStyle.useBetaStyle()) {
-			style = getDefaultStyleDefinitionPartition().getMergedStyle(skinParam.getCurrentStyleBuilder());
+			style = getStyleSignature().getMergedStyle(skinParam.getCurrentStyleBuilder());
 			fc = style.getFontConfiguration(skinParam.getThemeStyle(), getIHtmlColorSet());
 			this.shadowing = style.value(PName.Shadowing).asDouble();
+			this.backColor = backColor == null
+					? style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(), getIHtmlColorSet())
+					: backColor;
+			this.borderColor = borderColor == null
+					? style.value(PName.LineColor).asColor(skinParam.getThemeStyle(), getIHtmlColorSet())
+					: borderColor;
+			thickness = style.getStroke();
 		} else {
+			this.backColor = backColor == null ? HColorUtils.WHITE : backColor;
+			this.borderColor = borderColor == null ? HColorUtils.BLACK : borderColor;
 			style = null;
 			final UFont font = skinParam.getFont(null, false, FontParam.PARTITION);
 			final HColor fontColor = skinParam.getFontHtmlColor(null, FontParam.PARTITION);
 			fc = new FontConfiguration(font, fontColor, skinParam.getHyperlinkColor(),
 					skinParam.useUnderlineForHyperlink(), skinParam.getTabSize());
 			this.shadowing = skinParam().shadowing(null) ? 3 : 0;
+			thickness = skinParam.getThickness(LineParam.partitionBorder, null);
 		}
-		if (title == null) {
+		if (title == null)
 			this.name = TextBlockUtils.empty(0, 0);
-		} else {
+		else
 			this.name = title.create(fc, HorizontalAlignment.LEFT, skinParam);
-		}
-		if (Display.isNull(displayNote)) {
-			this.headerNote = TextBlockUtils.empty(0, 0);
-		} else {
-			this.headerNote = new FloatingNote(displayNote, skinParam, style);
-		}
 
-		final UStroke thickness = skinParam.getThickness(LineParam.partitionBorder, null);
+		if (Display.isNull(displayNote))
+			this.headerNote = TextBlockUtils.empty(0, 0);
+		else
+			this.headerNote = new FloatingNote(displayNote, skinParam);
+
 		this.stroke = thickness == null ? new UStroke(2) : thickness;
 	}
 
@@ -183,9 +190,9 @@ public class FtileGroup extends AbstractFtile {
 	private FtileGeometry cachedInnerDimension;
 
 	private FtileGeometry getInnerDimension(StringBounder stringBounder) {
-		if (cachedInnerDimension == null) {
+		if (cachedInnerDimension == null)
 			cachedInnerDimension = getInnerDimensionSlow(stringBounder);
-		}
+
 		return cachedInnerDimension;
 
 	}
@@ -208,10 +215,10 @@ public class FtileGroup extends AbstractFtile {
 		final double height = orig.getHeight() + diffHeightTitle(stringBounder) + diffYY2
 				+ headerNoteHeight(stringBounder);
 		final double titleAndHeaderNoteHeight = diffHeightTitle(stringBounder) + headerNoteHeight(stringBounder);
-		if (orig.hasPointOut()) {
+		if (orig.hasPointOut())
 			return new FtileGeometry(width, height, orig.getLeft() + suppWidth / 2,
 					orig.getInY() + titleAndHeaderNoteHeight, orig.getOutY() + titleAndHeaderNoteHeight);
-		}
+
 		return new FtileGeometry(width, height, orig.getLeft() + suppWidth / 2,
 				orig.getInY() + titleAndHeaderNoteHeight);
 	}
@@ -224,8 +231,6 @@ public class FtileGroup extends AbstractFtile {
 		final StringBounder stringBounder = ug.getStringBounder();
 		final Dimension2D dimTotal = calculateDimension(stringBounder);
 
-		// final double roundCorner =
-		// type.getSkinParameter().getRoundCorner(skinParam(), null);
 		final SymbolContext symbolContext = new SymbolContext(backColor, borderColor).withShadow(shadowing)
 				.withStroke(stroke).withCorner(roundCorner, 0);
 
