@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.ftile.vcompact;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -211,7 +211,7 @@ class FtileIfLongVertical extends AbstractFtile {
 		public void drawU(UGraphic ug) {
 			final UTranslate tr = getTranslateDiamond(getFtile2(), ug.getStringBounder());
 			final Point2D p2 = tr.getTranslated(getFtile2().calculateDimension(ug.getStringBounder()).getPointIn());
-			final Snake snake = Snake.create(arrowColor, Arrows.asToDown());
+			final Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown());
 			final Point2D p1 = calculateDimensionInternal(ug.getStringBounder()).getPointIn();
 
 			snake.addPoint(p1);
@@ -237,7 +237,7 @@ class FtileIfLongVertical extends AbstractFtile {
 			final Point2D p1 = getP1(stringBounder);
 			final Point2D p2 = getP2(stringBounder);
 
-			final Snake snake = Snake.create(color, Arrows.asToDown());
+			final Snake snake = Snake.create(skinParam(), color, Arrows.asToDown());
 			snake.addPoint(p1);
 			snake.addPoint(p2.getX(), p1.getY());
 			snake.addPoint(p2);
@@ -274,7 +274,8 @@ class FtileIfLongVertical extends AbstractFtile {
 			final Point2D p1 = getP1(stringBounder);
 			final Point2D p2 = getP2(stringBounder);
 
-			final Snake snake = Snake.create(color, Arrows.asToDown()).withLabel(label, VerticalAlignment.CENTER);
+			final Snake snake = Snake.create(skinParam(), color, Arrows.asToDown()).withLabel(label,
+					VerticalAlignment.CENTER);
 			snake.addPoint(p1);
 			snake.addPoint(p2);
 			ug.draw(snake);
@@ -312,7 +313,8 @@ class FtileIfLongVertical extends AbstractFtile {
 			final Point2D p2 = getTranslate2(stringBounder)
 					.getTranslated(getFtile2().calculateDimension(stringBounder).getPointIn());
 
-			final Snake snake = Snake.create(arrowColor, Arrows.asToDown()).withLabel(label, VerticalAlignment.CENTER);
+			final Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown()).withLabel(label,
+					VerticalAlignment.CENTER);
 			snake.addPoint(p1);
 			snake.addPoint(p1.getX(), p2.getY() - 15);
 			snake.addPoint(p2.getX(), p2.getY() - 15);
@@ -341,7 +343,7 @@ class FtileIfLongVertical extends AbstractFtile {
 			final Point2D p2 = getTranslateLastDiamond(stringBounder)
 					.getTranslated(getFtile2().calculateDimension(stringBounder).getPointIn());
 
-			final Snake snake = Snake.create(arrowColor, Arrows.asToDown());
+			final Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown());
 			snake.addPoint(p1);
 			snake.addPoint(p1.getX(), p2.getY() - 15);
 			snake.addPoint(p2.getX(), p2.getY() - 15);
@@ -375,7 +377,7 @@ class FtileIfLongVertical extends AbstractFtile {
 
 			final Dimension2D dimTotal = calculateDimensionInternal(stringBounder);
 
-			final Snake snake = Snake.create(arrowColor, Arrows.asToLeft());
+			final Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToLeft());
 			snake.addPoint(p1);
 			snake.addPoint(p1.getX(), p1.getY() + 15);
 			snake.addPoint(dimTotal.getWidth(), p1.getY() + 15);
@@ -406,7 +408,7 @@ class FtileIfLongVertical extends AbstractFtile {
 
 			final Point2D p2 = new Point2D.Double(dimTotal.getWidth(), p1.getY() + 15);
 
-			final Snake snake = Snake.create(arrowColor, Arrows.asToRight());
+			final Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToRight());
 			snake.addPoint(p1);
 			snake.addPoint(p1.getX(), p2.getY());
 			snake.addPoint(p2);
