@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.cond;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.List;
@@ -46,10 +46,10 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.AbstractConnection;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Arrows;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Connection;
 import net.sourceforge.plantuml.activitydiagram3.ftile.ConnectionTranslatable;
-import net.sourceforge.plantuml.activitydiagram3.ftile.Hexagon;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileGeometry;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileUtils;
+import net.sourceforge.plantuml.activitydiagram3.ftile.Hexagon;
 import net.sourceforge.plantuml.activitydiagram3.ftile.MergeStrategy;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Snake;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
@@ -100,7 +100,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			final double x2 = p2.getX();
 			final double y2 = p2.getY();
 
-			final Snake snake = Snake.create(color, usingArrow);
+			final Snake snake = Snake.create(skinParam(), color, usingArrow);
 			snake.addPoint(x1, y1);
 			snake.addPoint(x2, y1);
 			snake.addPoint(x2, y2);
@@ -147,14 +147,14 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			if (originalDirection != newDirection) {
 				final double delta = (originalDirection == Direction.RIGHT ? -1 : 1) * Hexagon.hexagonHalfSize;
 				final Dimension2D dimDiamond1 = diamond1.calculateDimension(stringBounder);
-				final Snake small = Snake.create(color);
+				final Snake small = Snake.create(skinParam(), color);
 				small.addPoint(p1);
 				small.addPoint(p1.getX() + delta, p1.getY());
 				small.addPoint(p1.getX() + delta, p1.getY() + dimDiamond1.getHeight() * .75);
 				ug.draw(small);
 				p1 = small.getLast();
 			}
-			final Snake snake = Snake.create(color, usingArrow).withMerge(MergeStrategy.LIMITED);
+			final Snake snake = Snake.create(skinParam(), color, usingArrow).withMerge(MergeStrategy.LIMITED);
 			snake.addPoint(p1);
 			snake.addPoint(p2.getX(), p1.getY());
 			snake.addPoint(p2);
@@ -190,7 +190,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			final double y2 = p2.getY();
 
 			final UPolygon arrow = x2 > x1 ? Arrows.asToRight() : Arrows.asToLeft();
-			Snake snake = Snake.create(myArrowColor, arrow);
+			Snake snake = Snake.create(skinParam(), myArrowColor, arrow);
 			if (branchEmpty) {
 				snake = snake.emphasizeDirection(Direction.DOWN);
 			}
@@ -244,14 +244,14 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			if (originalDirection == newDirection) {
 				final double delta = (x2 > x1 ? -1 : 1) * 1.5 * Hexagon.hexagonHalfSize;
 				final Point2D mp2bc = new Point2D.Double(mp2b.getX() + delta, mp2b.getY());
-				final Snake snake = Snake.create(myArrowColor).withMerge(MergeStrategy.LIMITED);
+				final Snake snake = Snake.create(skinParam(), myArrowColor).withMerge(MergeStrategy.LIMITED);
 				final double middle = (mp1a.getY() + mp2b.getY()) / 2.0;
 				snake.addPoint(mp1a);
 				snake.addPoint(mp1a.getX(), middle);
 				snake.addPoint(mp2bc.getX(), middle);
 				snake.addPoint(mp2bc);
 				ug.draw(snake);
-				final Snake small = Snake.create(myArrowColor, arrow).withMerge(MergeStrategy.LIMITED);
+				final Snake small = Snake.create(skinParam(), myArrowColor, arrow).withMerge(MergeStrategy.LIMITED);
 				small.addPoint(mp2bc);
 				small.addPoint(mp2bc.getX(), mp2b.getY());
 				small.addPoint(mp2b);
@@ -260,12 +260,12 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 				final double delta = (x2 > x1 ? -1 : 1) * 1.5 * Hexagon.hexagonHalfSize;
 				final Point2D mp2bb = new Point2D.Double(mp2b.getX() + delta,
 						mp2b.getY() - 1.5 * Hexagon.hexagonHalfSize);
-				final Snake snake = Snake.create(myArrowColor).withMerge(MergeStrategy.LIMITED);
+				final Snake snake = Snake.create(skinParam(), myArrowColor).withMerge(MergeStrategy.LIMITED);
 				snake.addPoint(mp1a);
 				snake.addPoint(mp1a.getX(), mp2bb.getY());
 				snake.addPoint(mp2bb);
 				ug.draw(snake);
-				final Snake small = Snake.create(myArrowColor, arrow).withMerge(MergeStrategy.LIMITED);
+				final Snake small = Snake.create(skinParam(), myArrowColor, arrow).withMerge(MergeStrategy.LIMITED);
 				small.addPoint(mp2bb);
 				small.addPoint(mp2bb.getX(), mp2b.getY());
 				small.addPoint(mp2b);
@@ -303,7 +303,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			final double x2 = p2.getX();
 			final double y2 = p2.getY();
 
-			Snake snake = Snake.create(myArrowColor);
+			Snake snake = Snake.create(skinParam(), myArrowColor);
 			if (branchEmpty) {
 				snake = snake.emphasizeDirection(Direction.DOWN);
 			}
@@ -330,7 +330,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			final Point2D mp1a = translate1.getTranslated(p1);
 			final Point2D mp2b = translate2.getTranslated(p2);
 
-			final Snake snake = Snake.create(myArrowColor).withMerge(MergeStrategy.LIMITED);
+			final Snake snake = Snake.create(skinParam(), myArrowColor).withMerge(MergeStrategy.LIMITED);
 			// snake.emphasizeDirection(Direction.DOWN);
 
 			final double x1 = mp1a.getX();
@@ -386,7 +386,8 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			}
 			final Point2D p2 = new Point2D.Double(p1.getX(), totalHeight);
 
-			final Snake snake = Snake.create(color, Arrows.asToDown()).withLabel(out2, arrowHorizontalAlignment());
+			final Snake snake = Snake.create(skinParam(), color, Arrows.asToDown()).withLabel(out2,
+					arrowHorizontalAlignment());
 			snake.addPoint(p1);
 			snake.addPoint(p2);
 			ug.draw(snake);
@@ -444,7 +445,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 				return;
 			}
 
-			final Snake s = Snake.create(arrowColor).withMerge(MergeStrategy.NONE);
+			final Snake s = Snake.create(skinParam(), arrowColor).withMerge(MergeStrategy.NONE);
 			s.addPoint(minX, totalDim.getHeight());
 			s.addPoint(maxX, totalDim.getHeight());
 			ug.draw(s);
