@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.gtile;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.util.Set;
 
 import net.sourceforge.plantuml.AlignmentParam;
@@ -63,7 +63,7 @@ import net.sourceforge.plantuml.skin.rose.Rose;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.style.StyleSignature;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.style.Styleable;
 import net.sourceforge.plantuml.svek.image.Opale;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -86,15 +86,15 @@ public class GtileWithNoteOpale extends AbstractGtile implements Stencil, Stylea
 	private final Dimension2D dimNote;
 	private final Dimension2D dimTile;
 
-	public StyleSignature getDefaultStyleDefinition() {
-		return StyleSignature.of(SName.root, SName.element, SName.activityDiagram, SName.note);
+	public StyleSignatureBasic getStyleSignature() {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.note);
 	}
-	
+
 	@Override
 	public Swimlane getSwimlane(String point) {
 		return tile.getSwimlane(point);
 	}
-	
+
 	@Override
 	public Set<Swimlane> getSwimlanes() {
 		return tile.getSwimlanes();
@@ -105,12 +105,11 @@ public class GtileWithNoteOpale extends AbstractGtile implements Stencil, Stylea
 		this.swimlaneNote = note.getSwimlaneNote();
 		if (note.getColors() != null)
 			skinParam = note.getColors().mute(skinParam);
-		
+
 		this.tile = tile;
 		this.notePosition = note.getNotePosition();
 		if (note.getType() == NoteType.FLOATING_NOTE)
 			withLink = false;
-		
 
 		final Rose rose = new Rose();
 
@@ -120,8 +119,9 @@ public class GtileWithNoteOpale extends AbstractGtile implements Stencil, Stylea
 
 		final double shadowing;
 		final LineBreakStrategy wrapWidth;
+		UStroke stroke = new UStroke();
 		if (UseStyle.useBetaStyle()) {
-			final Style style = getDefaultStyleDefinition().getMergedStyle(skinParam.getCurrentStyleBuilder())
+			final Style style = getStyleSignature().getMergedStyle(skinParam.getCurrentStyleBuilder())
 					.eventuallyOverride(note.getColors());
 			noteBackgroundColor = style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
 					getIHtmlColorSet());
@@ -129,6 +129,7 @@ public class GtileWithNoteOpale extends AbstractGtile implements Stencil, Stylea
 			fc = style.getFontConfiguration(skinParam.getThemeStyle(), getIHtmlColorSet());
 			shadowing = style.value(PName.Shadowing).asDouble();
 			wrapWidth = style.wrapWidth();
+			stroke = style.getStroke();
 		} else {
 			noteBackgroundColor = rose.getHtmlColor(skinParam, ColorParam.noteBackground);
 			borderColor = rose.getHtmlColor(skinParam, ColorParam.noteBorder);
@@ -142,7 +143,7 @@ public class GtileWithNoteOpale extends AbstractGtile implements Stencil, Stylea
 		final Sheet sheet = Parser.build(fc, align, skinParam, CreoleMode.FULL).createSheet(note.getDisplay());
 		final TextBlock text = new SheetBlock2(new SheetBlock1(sheet, wrapWidth, skinParam.getPadding()), this,
 				new UStroke(1));
-		this.opale = new Opale(shadowing, borderColor, noteBackgroundColor, text, withLink);
+		this.opale = new Opale(shadowing, borderColor, noteBackgroundColor, text, withLink, stroke);
 
 		this.dimNote = opale.calculateDimension(stringBounder);
 		this.dimTile = tile.calculateDimension(stringBounder);
