@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -38,7 +38,7 @@ package net.sourceforge.plantuml.code;
 import java.io.IOException;
 import java.io.StringReader;
 
-import net.sourceforge.plantuml.CharSequence2;
+import net.sourceforge.plantuml.StringLocated;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.command.regex.Matcher2;
 import net.sourceforge.plantuml.command.regex.MyPattern;
@@ -49,19 +49,19 @@ import net.sourceforge.plantuml.preproc.UncommentReadLine;
 
 public class ArobaseStringCompressor implements StringCompressor {
 
-	private final static Pattern2 p = MyPattern.cmpile("(?s)(?i)^[%s]*(@startuml[^\\n\\r]*)?[%s]*(.*?)[%s]*(@enduml)?[%s]*$");
+	private final static Pattern2 p = MyPattern.cmpile("(?s)^[%s]*(@startuml[^\\n\\r]*)?[%s]*(.*?)[%s]*(@enduml)?[%s]*$");
 
 	public String compress(final String data) throws IOException {
 		final ReadLine r = new UncommentReadLine(ReadLineReader.create(new StringReader(data), "COMPRESS"));
 		final StringBuilder sb = new StringBuilder();
 		final StringBuilder full = new StringBuilder();
-		CharSequence2 s = null;
+		StringLocated s = null;
 		boolean startDone = false;
 		while ((s = r.readLine()) != null) {
 			append(full, s);
-			if (s.toString2().startsWith("@startuml")) {
+			if (s.getString().startsWith("@startuml")) {
 				startDone = true;
-			} else if (s.toString2().startsWith("@enduml")) {
+			} else if (s.getString().startsWith("@enduml")) {
 				return sb.toString();
 			} else if (startDone) {
 				append(sb, s);
@@ -73,11 +73,11 @@ public class ArobaseStringCompressor implements StringCompressor {
 		return sb.toString();
 	}
 
-	private void append(final StringBuilder sb, CharSequence2 s) {
+	private void append(final StringBuilder sb, StringLocated s) {
 		if (sb.length() > 0) {
 			sb.append('\n');
 		}
-		sb.append(s.toString2());
+		sb.append(s.getString());
 	}
 
 	private String compressOld(String s) throws IOException {
@@ -88,7 +88,7 @@ public class ArobaseStringCompressor implements StringCompressor {
 		return "";
 	}
 
-	public String decompress(String s) throws IOException {
+	public String decompress(String s) {
 		String result = clean(s);
 		if (result.startsWith("@start")) {
 			return result;
@@ -102,7 +102,7 @@ public class ArobaseStringCompressor implements StringCompressor {
 	}
 
 	private String clean(String s) {
-		s = s.replace("\0", "");
+		// s = s.replace("\0", "");
 		s = StringUtils.trin(s);
 		s = clean1(s);
 		s = s.replaceAll("@enduml[^\\n\\r]*", "");
