@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -41,5 +41,5 @@ public interface Transcoder {
 
 	public String encode(String text) throws IOException;
 
-	public String decode(String code) throws IOException;
+	public String decode(String code) throws NoPlantumlCompressionException;
 }
