@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -36,6 +36,6 @@
 package net.sourceforge.plantuml.creole;
 
 public enum CreoleMode {
-	FULL, SIMPLE_LINE;
+	FULL, SIMPLE_LINE, NO_CREOLE;
 
 }
