@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,6 +35,16 @@
  */
 package net.sourceforge.plantuml.cucadiagram;
 
+import java.util.EnumSet;
+import java.util.Set;
+
 public enum EntityPortion {
-	FIELD, METHOD, CIRCLED_CHARACTER, STEREOTYPE, LOLLIPOP, ENTIRELY
+	FIELD, METHOD, MEMBER, CIRCLED_CHARACTER, STEREOTYPE;
+
+	public Set<EntityPortion> asSet() {
+		if (this == MEMBER) {
+			return EnumSet.<EntityPortion> of(FIELD, METHOD);
+		}
+		return EnumSet.<EntityPortion> of(this);
+	}
 }
