@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -38,8 +38,6 @@ package net.sourceforge.plantuml.cucadiagram.dot;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -47,16 +45,19 @@ import java.util.regex.Pattern;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.StringUtils;
+import net.sourceforge.plantuml.security.SFile;
+import net.sourceforge.plantuml.security.SecurityProfile;
+import net.sourceforge.plantuml.security.SecurityUtils;
 import net.sourceforge.plantuml.vizjs.GraphvizJs;
 import net.sourceforge.plantuml.vizjs.VizJsEngine;
 
 public class GraphvizUtils {
 
-	private static final String VIZJS = "vizjs";
+	public static final String VIZJS = "vizjs";
 	private static int DOT_VERSION_LIMIT = 226;
 
 	private static boolean isWindows() {
-		return File.separatorChar == '\\';
+		return SFile.separatorChar == '\\';
 	}
 
 	private static String dotExecutable;
@@ -66,7 +67,26 @@ public class GraphvizUtils {
 	}
 
 	public static final void setDotExecutable(String value) {
-		dotExecutable = value;
+		dotExecutable = value == null ? null : value.trim();
+	}
+
+	public static Graphviz createForSystemDot(ISkinParam skinParam, String dotString, String... type) {
+		if (useVizJs(skinParam)) {
+			Log.info("Using " + VIZJS);
+			return new GraphvizJs(dotString);
+		}
+		final AbstractGraphviz result;
+		if (isWindows()) {
+			result = new GraphvizWindowsOld(skinParam, dotString, type);
+		} else {
+			result = new GraphvizLinux(skinParam, dotString, type);
+		}
+		if (result.getExeState() != ExeState.OK && VizJsEngine.isOk()) {
+			Log.info("Error with file " + result.getDotExe() + ": " + result.getExeState().getTextMessage());
+			Log.info("Using " + VIZJS);
+			return new GraphvizJs(dotString);
+		}
+		return result;
 	}
 
 	public static Graphviz create(ISkinParam skinParam, String dotString, String... type) {
@@ -76,7 +96,7 @@ public class GraphvizUtils {
 		}
 		final AbstractGraphviz result;
 		if (isWindows()) {
-			result = new GraphvizWindows(skinParam, dotString, type);
+			result = new GraphvizWindowsLite(skinParam, dotString, type);
 		} else {
 			result = new GraphvizLinux(skinParam, dotString, type);
 		}
@@ -89,7 +109,7 @@ public class GraphvizUtils {
 	}
 
 	private static boolean useVizJs(ISkinParam skinParam) {
-		if (skinParam != null && VIZJS.equalsIgnoreCase(skinParam.getDotExecutable()) && VizJsEngine.isOk()) {
+		if (skinParam != null && skinParam.isUseVizJs() && VizJsEngine.isOk()) {
 			return true;
 		}
 		if (VIZJS.equalsIgnoreCase(getenvGraphvizDot()) && VizJsEngine.isOk()) {
@@ -117,7 +137,7 @@ public class GraphvizUtils {
 		return null;
 	}
 
-	private static final ThreadLocal<Integer> limitSize = new ThreadLocal<Integer>();
+	private static final ThreadLocal<Integer> limitSize = new ThreadLocal<>();
 
 	public static void removeLocalLimitSize() {
 		limitSize.remove();
@@ -132,23 +152,19 @@ public class GraphvizUtils {
 		if (local != null) {
 			return local;
 		}
-		final String env = System.getProperty("PLANTUML_LIMIT_SIZE");
+		final String env = SecurityUtils.getenv("PLANTUML_LIMIT_SIZE");
 		if (StringUtils.isNotEmpty(env) && env.matches("\\d+")) {
 			return Integer.parseInt(env);
 		}
-		final String getenv = System.getenv("PLANTUML_LIMIT_SIZE");
-		if (StringUtils.isNotEmpty(getenv) && getenv.matches("\\d+")) {
-			return Integer.parseInt(getenv);
-		}
 		return 4096;
 	}
 
+	public static String getenvDefaultConfigFilename() {
+		return SecurityUtils.getenv("PLANTUML_DEFAULT_CONFIG_FILENAME");
+	}
+
 	public static String getenvLogData() {
-		final String env = System.getProperty("PLANTUML_LOGDATA");
-		if (StringUtils.isNotEmpty(env)) {
-			return env;
-		}
-		return System.getenv("PLANTUML_LOGDATA");
+		return SecurityUtils.getenv("PLANTUML_LOGDATA");
 	}
 
 	private static String dotVersion = null;
@@ -166,6 +182,15 @@ public class GraphvizUtils {
 		return dotVersion;
 	}
 
+	public static boolean graphviz244onWindows() {
+		try {
+			return create(null, "png").graphviz244onWindows();
+		} catch (Exception e) {
+			e.printStackTrace();
+			return false;
+		}
+	}
+
 	public static int retrieveVersion(String s) {
 		if (s == null) {
 			return -1;
@@ -182,7 +207,7 @@ public class GraphvizUtils {
 		return retrieveVersion(dotVersion());
 	}
 
-	static public List<String> getTestDotStrings(boolean withRichText) {
+	static public int addDotStatus(List<String> result, boolean withRichText) {
 		String red = "";
 		String bold = "";
 		if (withRichText) {
@@ -190,7 +215,8 @@ public class GraphvizUtils {
 			bold = "<b>";
 		}
 
-		final List<String> result = new ArrayList<String>();
+		int error = 0;
+
 		if (useVizJs(null)) {
 			result.add("VizJs library is used!");
 			try {
@@ -203,19 +229,21 @@ public class GraphvizUtils {
 			} catch (Exception e) {
 				result.add(red + e.toString());
 				e.printStackTrace();
+				error = -1;
 			}
-			return Collections.unmodifiableList(result);
+			return error;
 		}
 
-		final String ent = GraphvizUtils.getenvGraphvizDot();
-		if (ent == null) {
-			result.add("The environment variable GRAPHVIZ_DOT has not been set");
-		} else {
-			result.add("The environment variable GRAPHVIZ_DOT has been set to " + ent);
-		}
 		final File dotExe = GraphvizUtils.getDotExe();
-		result.add("Dot executable is " + dotExe);
-
+		if (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE) {
+			final String ent = GraphvizUtils.getenvGraphvizDot();
+			if (ent == null) {
+				result.add("The environment variable GRAPHVIZ_DOT has not been set");
+			} else {
+				result.add("The environment variable GRAPHVIZ_DOT has been set to " + ent);
+			}
+			result.add("Dot executable is " + dotExe);
+		}
 		final ExeState exeState = ExeState.checkFile(dotExe);
 
 		if (exeState == ExeState.OK) {
@@ -225,27 +253,32 @@ public class GraphvizUtils {
 				final int v = GraphvizUtils.getDotVersion();
 				if (v == -1) {
 					result.add("Warning : cannot determine dot version");
+					error = -2;
 				} else if (v < DOT_VERSION_LIMIT) {
 					result.add(bold + "Warning : Your dot installation seems old");
 					result.add(bold + "Some diagrams may have issues");
+					error = -3;
 				} else {
 					final String err = getTestCreateSimpleFile();
 					if (err == null) {
 						result.add(bold + "Installation seems OK. File generation OK");
 					} else {
 						result.add(red + err);
+						error = -4;
 					}
 				}
 			} catch (Exception e) {
 				result.add(red + e.toString());
 				e.printStackTrace();
+				error = -5;
 			}
 		} else {
 			result.add(red + "Error: " + exeState.getTextMessage());
 			result.add("Error: only sequence diagrams will be generated");
+			error = -6;
 		}
 
-		return Collections.unmodifiableList(result);
+		return error;
 	}
 
 	static String getTestCreateSimpleFile() throws IOException {
