@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -72,6 +72,7 @@ import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.cucadiagram.dot.Neighborhood;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.USymbol;
+import net.sourceforge.plantuml.graphic.USymbols;
 import net.sourceforge.plantuml.graphic.color.ColorType;
 import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.skin.VisibilityModifier;
@@ -576,7 +577,7 @@ final public class EntityImpl implements ILeaf, IGroup {
 
 	public USymbol getUSymbol() {
 		if (getLeafType() == LeafType.CIRCLE) {
-			return USymbol.INTERFACE;
+			return USymbols.INTERFACE;
 		}
 		// if (symbol != null && stereotype != null && stereotype.getSprite() != null) {
 		// return symbol.withStereoAlignment(HorizontalAlignment.RIGHT);
