@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,8 +35,7 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-
-interface Line extends TextBlock {
+public interface Line extends TextBlock {
 
 	HorizontalAlignment getHorizontalAlignment();
 }
\ No newline at end of file
