@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.style.SName;
@@ -52,13 +52,12 @@ class USymbolCard extends USymbol {
 	public USymbolCard(SkinParameter skinParameter) {
 		this.skinParameter = skinParameter;
 	}
-	
+
 	@Override
 	public SName getSName() {
 		return SName.card;
 	}
 
-
 	@Override
 	public SkinParameter getSkinParameter() {
 		return skinParameter;
