@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.style.SName;
@@ -51,13 +51,12 @@ class USymbolComponent2 extends USymbol {
 	public SkinParameter getSkinParameter() {
 		return SkinParameter.COMPONENT2;
 	}
-	
+
 	@Override
 	public SName getSName() {
 		return SName.component;
 	}
 
-
 	private void drawComponent2(UGraphic ug, double widthTotal, double heightTotal, double shadowing,
 			double roundCorner) {
 
