@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
@@ -55,13 +55,12 @@ class USymbolFile extends USymbol {
 	public SkinParameter getSkinParameter() {
 		return SkinParameter.FILE;
 	}
-	
+
 	@Override
 	public SName getSName() {
 		return SName.file;
 	}
 
-
 	private void drawFile(UGraphic ug, double width, double height, double shadowing, double roundCorner) {
 		final int cornersize = 10;
 		final Shadowable out;
