@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.UseStyle;
@@ -57,13 +57,12 @@ class USymbolNode extends USymbol {
 	public SkinParameter getSkinParameter() {
 		return SkinParameter.NODE;
 	}
-	
+
 	@Override
 	public SName getSName() {
 		return SName.node;
 	}
 
-
 //	public USymbolNode(HorizontalAlignment stereotypeAlignement) {
 //		this.stereotypeAlignement = stereotypeAlignement;
 //	}
