@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,7 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.creole.Stencil;
@@ -53,13 +53,12 @@ class USymbolQueue extends USymbol {
 	public SkinParameter getSkinParameter() {
 		return SkinParameter.QUEUE;
 	}
-	
+
 	@Override
 	public SName getSName() {
 		return SName.queue;
 	}
 
-
 	private final double dx = 5;
 
 	private void drawQueue(UGraphic ug, double width, double height, double shadowing) {
