@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -68,12 +68,12 @@ public class MDADiagramImpl implements MDADiagram {
 		return null;
 	}
 
-	private final Collection<MDAPackage> packages = new ArrayList<MDAPackage>();
+	private final Collection<MDAPackage> packages = new ArrayList<>();
 
 	private MDADiagramImpl(ClassDiagram classDiagram) {
 		final EntityFactory entityFactory = classDiagram.getEntityFactory();
 		packages.add(new MDAPackageImpl(entityFactory.getRootGroup()));
-		for (IGroup group : entityFactory.getGroupsvalues()) {
+		for (IGroup group : entityFactory.groups()) {
 			packages.add(new MDAPackageImpl(group));
 		}
 	}
