@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
- * 
+ *
  * If you like this project or if you find it useful, you can support us at:
- * 
+ *
  * http://plantuml.com/patreon (only 1$ per month!)
  * http://plantuml.com/paypal
- * 
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,8 +30,9 @@
  *
  *
  * Original Author:  Arnaud Roques
+ * Contribution:  Miguel Esteves
+ *
  *
- * 
  */
 package net.sourceforge.plantuml.posimo;
 
@@ -45,19 +46,22 @@ import java.awt.geom.Rectangle2D;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.StringTokenizer;
+import java.util.Objects;
+import java.util.Set;
 
 import net.sourceforge.plantuml.EnsureVisible;
 import net.sourceforge.plantuml.asciiart.BasicCharArea;
 import net.sourceforge.plantuml.eps.EpsGraphics;
-import net.sourceforge.plantuml.geom.LineSegmentDouble;
 import net.sourceforge.plantuml.svek.Cluster;
 import net.sourceforge.plantuml.svek.ClusterPosition;
 import net.sourceforge.plantuml.svek.MinFinder;
 import net.sourceforge.plantuml.svek.PointAndAngle;
 import net.sourceforge.plantuml.svek.PointDirected;
+import net.sourceforge.plantuml.svek.SvgResult;
 import net.sourceforge.plantuml.ugraphic.MinMax;
 import net.sourceforge.plantuml.ugraphic.UPath;
 import net.sourceforge.plantuml.ugraphic.USegmentType;
@@ -66,16 +70,13 @@ import net.sourceforge.plantuml.ugraphic.UShape;
 public class DotPath implements UShape, Moveable {
 
 	static class TriPoints {
-		public TriPoints(String p1, String p2, String p, double deltaY) {
-			final StringTokenizer st1 = new StringTokenizer(p1, ",");
-			x1 = Double.parseDouble(st1.nextToken());
-			y1 = Double.parseDouble(st1.nextToken()) + deltaY;
-			final StringTokenizer st2 = new StringTokenizer(p2, ",");
-			x2 = Double.parseDouble(st2.nextToken());
-			y2 = Double.parseDouble(st2.nextToken()) + deltaY;
-			final StringTokenizer st = new StringTokenizer(p, ",");
-			x = Double.parseDouble(st.nextToken());
-			y = Double.parseDouble(st.nextToken()) + deltaY;
+		public TriPoints(Point2D.Double p1, Point2D.Double p2, Point2D.Double p) {
+			x1 = p1.getX();
+			y1 = p1.getY();
+			x2 = p2.getX();
+			y2 = p2.getY();
+			x = p.getX();
+			y = p.getY();
 		}
 
 		private final double x1;
@@ -92,29 +93,60 @@ public class DotPath implements UShape, Moveable {
 		// }
 	}
 
-	private final List<CubicCurve2D.Double> beziers = new ArrayList<CubicCurve2D.Double>();
+	private final List<CubicCurve2D.Double> beziers = new ArrayList<>();
 	private String comment;
+	private String codeLine;
+
+	public DotPath copy() {
+		final DotPath result = new DotPath();
+		for (CubicCurve2D.Double c : this.beziers)
+			result.beziers.add(new CubicCurve2D.Double(c.x1, c.y1, c.ctrlx1, c.ctrly1, c.ctrlx2, c.ctrly2, c.x2, c.y2));
+
+		return result;
+	}
+
+	private static DotPath fromBeziers(List<CubicCurve2D.Double> beziers) {
+		final DotPath result = new DotPath();
+		result.beziers.addAll(Objects.requireNonNull(beziers));
+		return result;
+	}
 
 	public DotPath() {
-		this(new ArrayList<CubicCurve2D.Double>());
 	}
 
-	public DotPath(DotPath other) {
-		this(new ArrayList<CubicCurve2D.Double>());
-		for (CubicCurve2D.Double c : other.beziers) {
-			this.beziers.add(new CubicCurve2D.Double(c.x1, c.y1, c.ctrlx1, c.ctrly1, c.ctrlx2, c.ctrly2, c.x2, c.y2));
+	public DotPath(SvgResult fullSvg) {
+		if (isPathConsistent(fullSvg.getSvg()) == false) {
+			throw new IllegalArgumentException();
 		}
-	}
+		final int posC = fullSvg.indexOf("C", 0);
+		if (posC == -1)
+			throw new IllegalArgumentException();
 
-	private DotPath(List<CubicCurve2D.Double> beziers) {
-		this.beziers.addAll(beziers);
+		final Point2D start = fullSvg.substring(1, posC).getNextPoint();
+
+		final List<TriPoints> triPoints = new ArrayList<>();
+		for (Iterator<Point2D.Double> it = fullSvg.substring(posC + 1).getPoints(" ").iterator(); it.hasNext();) {
+			final Point2D.Double p1 = it.next();
+			final Point2D.Double p2 = it.next();
+			final Point2D.Double p = it.next();
+			triPoints.add(new TriPoints(p1, p2, p));
+		}
+		double x = start.getX();
+		double y = start.getY();
+		for (TriPoints p : triPoints) {
+			final CubicCurve2D.Double bezier = new CubicCurve2D.Double(x, y, p.x1, p.y1, p.x2, p.y2, p.x, p.y);
+			beziers.add(bezier);
+			x = p.x;
+			y = p.y;
+		}
+		// this.print = triPoints.toString();
 	}
 
 	public DotPath addCurve(Point2D pt1, Point2D pt2, Point2D pt3, Point2D pt4) {
-		final List<CubicCurve2D.Double> beziersNew = new ArrayList<CubicCurve2D.Double>(beziers);
+		final List<CubicCurve2D.Double> beziersNew = new ArrayList<>(beziers);
 		beziersNew.add(new CubicCurve2D.Double(pt1.getX(), pt1.getY(), pt2.getX(), pt2.getY(), pt3.getX(), pt3.getY(),
 				pt4.getX(), pt4.getY()));
-		return new DotPath(beziersNew);
+		return fromBeziers(beziersNew);
 	}
 
 	public DotPath addCurve(Point2D pt2, Point2D pt3, Point2D pt4) {
@@ -129,41 +161,10 @@ public class DotPath implements UShape, Moveable {
 		return new Point2D.Double(x, y);
 	}
 
-	public DotPath(String init, double deltaY) {
-		if (isPathConsistent(init) == false) {
-			throw new IllegalArgumentException();
-		}
-		final int posC = init.indexOf("C");
-		if (posC == -1) {
-			throw new IllegalArgumentException();
-		}
-		final StringTokenizer st = new StringTokenizer(init.substring(1, posC), ",");
-		final double startX = Double.parseDouble(st.nextToken());
-		final double startY = Double.parseDouble(st.nextToken()) + deltaY;
-
-		final StringTokenizer st2 = new StringTokenizer(init.substring(posC + 1), " ");
-		final List<TriPoints> triPoints = new ArrayList<TriPoints>();
-		while (st2.hasMoreTokens()) {
-			final String p1 = st2.nextToken();
-			final String p2 = st2.nextToken();
-			final String p = st2.nextToken();
-			triPoints.add(new TriPoints(p1, p2, p, deltaY));
-		}
-		double x = startX;
-		double y = startY;
-		for (TriPoints p : triPoints) {
-			final CubicCurve2D.Double bezier = new CubicCurve2D.Double(x, y, p.x1, p.y1, p.x2, p.y2, p.x, p.y);
-			beziers.add(bezier);
-			x = p.x;
-			y = p.y;
-		}
-		// this.print = triPoints.toString();
-	}
-
 	public static boolean isPathConsistent(String init) {
-		if (init.startsWith("M") == false) {
+		if (init.startsWith("M") == false)
 			return false;
-		}
+
 		return true;
 	}
 
@@ -173,6 +174,29 @@ public class DotPath implements UShape, Moveable {
 		return beziers.get(0).getP1();
 	}
 
+	public Set<Point2D> sample() {
+		final Set<Point2D> result = new HashSet<>();
+		for (CubicCurve2D.Double bez : beziers)
+			sample(bez, result);
+
+		return Collections.unmodifiableSet(result);
+	}
+
+	private static void sample(CubicCurve2D bez, Set<Point2D> result) {
+		final Point2D p1 = bez.getCtrlP1();
+		final Point2D p2 = bez.getCtrlP2();
+		if (bez.getFlatnessSq() > 0.5 || p1.distance(p2) > 4) {
+			final CubicCurve2D.Double left = new CubicCurve2D.Double();
+			final CubicCurve2D.Double right = new CubicCurve2D.Double();
+			bez.subdivide(left, right);
+			sample(left, result);
+			sample(right, result);
+		} else {
+			result.add(p1);
+			result.add(p2);
+		}
+	}
+
 	public PointAndAngle getMiddle() {
 		Point2D result = null;
 		double angle = 0;
@@ -316,31 +340,31 @@ public class DotPath implements UShape, Moveable {
 	}
 
 	public DotPath addBefore(CubicCurve2D.Double before) {
-		final List<CubicCurve2D.Double> copy = new ArrayList<CubicCurve2D.Double>(beziers);
+		final List<CubicCurve2D.Double> copy = new ArrayList<>(beziers);
 		copy.add(0, before);
-		return new DotPath(copy);
+		return fromBeziers(copy);
 	}
 
 	private DotPath addBefore(DotPath other) {
-		final List<CubicCurve2D.Double> copy = new ArrayList<CubicCurve2D.Double>(beziers);
+		final List<CubicCurve2D.Double> copy = new ArrayList<>(beziers);
 		copy.addAll(0, other.beziers);
-		return new DotPath(copy);
+		return fromBeziers(copy);
 	}
 
 	public DotPath addAfter(CubicCurve2D.Double after) {
-		final List<CubicCurve2D.Double> copy = new ArrayList<CubicCurve2D.Double>(beziers);
+		final List<CubicCurve2D.Double> copy = new ArrayList<>(beziers);
 		copy.add(after);
-		return new DotPath(copy);
+		return fromBeziers(copy);
 	}
 
 	public DotPath addAfter(DotPath other) {
-		final List<CubicCurve2D.Double> copy = new ArrayList<CubicCurve2D.Double>(beziers);
+		final List<CubicCurve2D.Double> copy = new ArrayList<>(beziers);
 		copy.addAll(other.beziers);
-		return new DotPath(copy);
+		return fromBeziers(copy);
 	}
 
 	public Map<Point2D, Double> somePoints() {
-		final Map<Point2D, Double> result = new HashMap<Point2D, Double>();
+		final Map<Point2D, Double> result = new HashMap<>();
 		for (CubicCurve2D.Double bez : beziers) {
 			final CubicCurve2D.Double left = new CubicCurve2D.Double();
 			final CubicCurve2D.Double right = new CubicCurve2D.Double();
@@ -366,8 +390,8 @@ public class DotPath implements UShape, Moveable {
 	public void draw(Graphics2D g2d, double x, double y) {
 		final GeneralPath p = new GeneralPath();
 		for (CubicCurve2D.Double bez : beziers) {
-			bez = new CubicCurve2D.Double(x + bez.x1, y + bez.y1, x + bez.ctrlx1, y + bez.ctrly1, x + bez.ctrlx2, y
-					+ bez.ctrly2, x + bez.x2, y + bez.y2);
+			bez = new CubicCurve2D.Double(x + bez.x1, y + bez.y1, x + bez.ctrlx1, y + bez.ctrly1, x + bez.ctrlx2,
+					y + bez.ctrly2, x + bez.x2, y + bez.y2);
 			p.append(bez, true);
 		}
 		g2d.draw(p);
@@ -384,8 +408,8 @@ public class DotPath implements UShape, Moveable {
 	public void drawOk(EpsGraphics eps, double x, double y) {
 		// boolean first = true;
 		for (CubicCurve2D.Double bez : beziers) {
-			bez = new CubicCurve2D.Double(x + bez.x1, y + bez.y1, x + bez.ctrlx1, y + bez.ctrly1, x + bez.ctrlx2, y
-					+ bez.ctrly2, x + bez.x2, y + bez.y2);
+			bez = new CubicCurve2D.Double(x + bez.x1, y + bez.y1, x + bez.ctrlx1, y + bez.ctrly1, x + bez.ctrlx2,
+					y + bez.ctrly2, x + bez.x2, y + bez.y2);
 			eps.epsLine(bez.x1, bez.y1, bez.x2, bez.y2);
 		}
 	}
@@ -395,8 +419,8 @@ public class DotPath implements UShape, Moveable {
 		final boolean dashed = false;
 		boolean first = true;
 		for (CubicCurve2D.Double bez : beziers) {
-			bez = new CubicCurve2D.Double(x + bez.x1, y + bez.y1, x + bez.ctrlx1, y + bez.ctrly1, x + bez.ctrlx2, y
-					+ bez.ctrly2, x + bez.x2, y + bez.y2);
+			bez = new CubicCurve2D.Double(x + bez.x1, y + bez.y1, x + bez.ctrlx1, y + bez.ctrly1, x + bez.ctrlx2,
+					y + bez.ctrly2, x + bez.x2, y + bez.y2);
 			if (first) {
 				eps.movetoNoMacro(bez.x1, bez.y1);
 				first = dashed;
@@ -407,7 +431,7 @@ public class DotPath implements UShape, Moveable {
 	}
 
 	public UPath toUPath() {
-		final UPath result = new UPath(comment);
+		final UPath result = new UPath(comment, codeLine);
 		boolean start = true;
 		for (CubicCurve2D.Double bez : beziers) {
 			if (start) {
@@ -422,22 +446,22 @@ public class DotPath implements UShape, Moveable {
 	}
 
 	private Point2D getFrontierIntersection(Shape shape, Rectangle2D... notIn) {
-		final List<CubicCurve2D.Double> all = new ArrayList<CubicCurve2D.Double>(beziers);
+		final List<CubicCurve2D.Double> all = new ArrayList<>(beziers);
 		for (int i = 0; i < 8; i++) {
 			for (CubicCurve2D.Double immutable : all) {
-				if (contains(immutable, notIn)) {
+				if (contains(immutable, notIn))
 					continue;
-				}
+
 				final CubicCurve2D.Double bez = new CubicCurve2D.Double();
 				bez.setCurve(immutable);
 				if (BezierUtils.isCutting(bez, shape)) {
-					while (BezierUtils.dist(bez) > 1.0) {
+					while (BezierUtils.dist(bez) > 1.0)
 						BezierUtils.shorten(bez, shape);
-					}
+
 					final Point2D.Double result = new Point2D.Double((bez.x1 + bez.x2) / 2, (bez.y1 + bez.y2) / 2);
-					if (contains(result, notIn) == false) {
+					if (contains(result, notIn) == false)
 						return result;
-					}
+
 				}
 			}
 			cutAllCubic(all);
@@ -446,7 +470,7 @@ public class DotPath implements UShape, Moveable {
 	}
 
 	private void cutAllCubic(List<CubicCurve2D.Double> all) {
-		final List<CubicCurve2D.Double> tmp = new ArrayList<CubicCurve2D.Double>(all);
+		final List<CubicCurve2D.Double> tmp = new ArrayList<>(all);
 		all.clear();
 		for (CubicCurve2D.Double bez : tmp) {
 			final CubicCurve2D.Double left = new CubicCurve2D.Double();
@@ -458,42 +482,40 @@ public class DotPath implements UShape, Moveable {
 	}
 
 	static private boolean contains(Point2D.Double point, Rectangle2D... rects) {
-		for (Rectangle2D r : rects) {
-			if (r.contains(point)) {
+		for (Rectangle2D r : rects)
+			if (r.contains(point))
 				return true;
-			}
-		}
+
 		return false;
 	}
 
 	static private boolean contains(CubicCurve2D.Double cubic, Rectangle2D... rects) {
-		for (Rectangle2D r : rects) {
-			if (r.contains(cubic.getP1()) && r.contains(cubic.getP2())) {
+		for (Rectangle2D r : rects)
+			if (r.contains(cubic.getP1()) && r.contains(cubic.getP2()))
 				return true;
-			}
-		}
+
 		return false;
 	}
 
 	private DotPath manageRect(Rectangle2D start, Rectangle2D end) {
-		final List<CubicCurve2D.Double> list = new ArrayList<CubicCurve2D.Double>(this.beziers);
+		final List<CubicCurve2D.Double> list = new ArrayList<>(this.beziers);
 		while (true) {
-			if (BezierUtils.isCutting(list.get(0), start) == false) {
+			if (BezierUtils.isCutting(list.get(0), start) == false)
 				throw new IllegalStateException();
-			}
-			if (BezierUtils.dist(list.get(0)) <= 1.0) {
+
+			if (BezierUtils.dist(list.get(0)) <= 1.0)
 				break;
-			}
+
 			final CubicCurve2D.Double left = new CubicCurve2D.Double();
 			final CubicCurve2D.Double right = new CubicCurve2D.Double();
 			list.get(0).subdivide(left, right);
 			list.set(0, left);
 			list.add(1, right);
-			if (BezierUtils.isCutting(list.get(1), start)) {
+			if (BezierUtils.isCutting(list.get(1), start))
 				list.remove(0);
-			}
+
 		}
-		return new DotPath(list);
+		return fromBeziers(list);
 	}
 
 	private Point2D getFrontierIntersection(Positionable p) {
@@ -501,22 +523,19 @@ public class DotPath implements UShape, Moveable {
 	}
 
 	public void draw(BasicCharArea area, double pixelXPerChar, double pixelYPerChar) {
-		for (CubicCurve2D.Double bez : beziers) {
-			if (bez.x1 == bez.x2) {
+		for (CubicCurve2D.Double bez : beziers)
+			if (bez.x1 == bez.x2)
 				area.drawVLine('|', (int) (bez.x1 / pixelXPerChar), (int) (bez.y1 / pixelYPerChar),
 						(int) (bez.y2 / pixelYPerChar));
-			} else if (bez.y1 == bez.y2) {
+			else if (bez.y1 == bez.y2)
 				area.drawHLine('-', (int) (bez.y1 / pixelYPerChar), (int) (bez.x1 / pixelXPerChar),
 						(int) (bez.x2 / pixelXPerChar));
-			} /*
-			 * else { throw new UnsupportedOperationException("bez=" + toString(bez)); }
-			 */
-		}
+
 	}
 
 	static String toString(CubicCurve2D.Double c) {
-		return "(" + c.x1 + "," + c.y1 + ") " + "(" + c.ctrlx1 + "," + c.ctrly1 + ") " + "(" + c.ctrlx2 + ","
-				+ c.ctrly2 + ") " + "(" + c.x2 + "," + c.y2 + ") ";
+		return "(" + c.x1 + "," + c.y1 + ") " + "(" + c.ctrlx1 + "," + c.ctrly1 + ") " + "(" + c.ctrlx2 + "," + c.ctrly2
+				+ ") " + "(" + c.x2 + "," + c.y2 + ") ";
 
 	}
 
@@ -531,18 +550,18 @@ public class DotPath implements UShape, Moveable {
 	}
 
 	public static CubicCurve2D.Double reverse(CubicCurve2D curv) {
-		return new CubicCurve2D.Double(curv.getX2(), curv.getY2(), curv.getCtrlX2(), curv.getCtrlY2(),
-				curv.getCtrlX1(), curv.getCtrlY1(), curv.getX1(), curv.getY1());
+		return new CubicCurve2D.Double(curv.getX2(), curv.getY2(), curv.getCtrlX2(), curv.getCtrlY2(), curv.getCtrlX1(),
+				curv.getCtrlY1(), curv.getX1(), curv.getY1());
 	}
 
 	public DotPath reverse() {
-		final List<CubicCurve2D.Double> reverse = new ArrayList<CubicCurve2D.Double>(beziers);
+		final List<CubicCurve2D.Double> reverse = new ArrayList<>(beziers);
 		Collections.reverse(reverse);
-		final List<CubicCurve2D.Double> copy = new ArrayList<CubicCurve2D.Double>();
-		for (CubicCurve2D.Double cub : reverse) {
+		final List<CubicCurve2D.Double> copy = new ArrayList<>();
+		for (CubicCurve2D.Double cub : reverse)
 			copy.add(reverse(cub));
-		}
-		return new DotPath(copy);
+
+		return fromBeziers(copy);
 
 	}
 
@@ -658,19 +677,9 @@ public class DotPath implements UShape, Moveable {
 		return true;
 	}
 
-	public List<LineSegmentDouble> getLineSegments() {
-		final List<LineSegmentDouble> result = new ArrayList<LineSegmentDouble>();
-		for (CubicCurve2D.Double curve : beziers) {
-			if (curve.getFlatnessSq() <= 0.001) {
-				result.add(new LineSegmentDouble(curve));
-
-			}
-		}
-		return Collections.unmodifiableList(result);
-	}
-
-	public void setComment(String comment) {
+	public void setCommentAndCodeLine(String comment, String codeLine) {
 		this.comment = comment;
+		this.codeLine = codeLine;
 	}
 
 }
