@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -39,9 +39,10 @@ import java.util.ArrayList;
 import java.util.List;
 
 import net.sourceforge.plantuml.ISkinSimple;
+import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.command.Command;
-import net.sourceforge.plantuml.command.PSystemCommandFactory;
 import net.sourceforge.plantuml.command.CommonCommands;
+import net.sourceforge.plantuml.command.PSystemCommandFactory;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
 
@@ -66,8 +67,8 @@ public class PSystemSaltFactory2 extends PSystemCommandFactory {
 	}
 
 	@Override
-	public PSystemSalt createEmptyDiagram(UmlSource source, ISkinSimple skinParam) {
-		final PSystemSalt result = new PSystemSalt(source);
+	public PSystemSalt createEmptyDiagram(ThemeStyle style, UmlSource source, ISkinSimple skinParam) {
+		final PSystemSalt result = new PSystemSalt(style, source);
 		if (getDiagramType() == DiagramType.SALT) {
 			result.setIamSalt(true);
 		}
