@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -58,6 +58,9 @@ public enum SName {
 	collection, //
 	collections, //
 	component, //
+	robust, //
+	concise, //
+	clock, //
 	componentDiagram, //
 	constraintArrow, //
 	control, //
@@ -69,6 +72,7 @@ public enum SName {
 	element, //
 	entity, //
 	end, //
+	start, //
 	stop, //
 	file, //
 	folder, //
