@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -37,7 +37,6 @@
  */
 package net.sourceforge.plantuml.svek;
 
-import java.awt.geom.Dimension2D;
 import java.awt.geom.Rectangle2D;
 import java.io.File;
 import java.io.IOException;
@@ -65,6 +64,7 @@ import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.UmlDiagramType;
 import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.activitydiagram3.ftile.EntityImageLegend;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import net.sourceforge.plantuml.core.UmlSource;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.cucadiagram.DisplayPositioned;
@@ -101,10 +101,12 @@ import net.sourceforge.plantuml.graphic.TextBlockUtils;
 import net.sourceforge.plantuml.graphic.USymbol;
 import net.sourceforge.plantuml.graphic.USymbolHexagon;
 import net.sourceforge.plantuml.graphic.USymbolInterface;
+import net.sourceforge.plantuml.graphic.USymbols;
+import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.style.StyleSignature;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.image.EntityImageActivity;
 import net.sourceforge.plantuml.svek.image.EntityImageArcCircle;
 import net.sourceforge.plantuml.svek.image.EntityImageAssociation;
@@ -117,6 +119,7 @@ import net.sourceforge.plantuml.svek.image.EntityImageDeepHistory;
 import net.sourceforge.plantuml.svek.image.EntityImageDescription;
 import net.sourceforge.plantuml.svek.image.EntityImageEmptyPackage;
 import net.sourceforge.plantuml.svek.image.EntityImageGroup;
+import net.sourceforge.plantuml.svek.image.EntityImageJson;
 import net.sourceforge.plantuml.svek.image.EntityImageLollipopInterface;
 import net.sourceforge.plantuml.svek.image.EntityImageLollipopInterfaceEye1;
 import net.sourceforge.plantuml.svek.image.EntityImageLollipopInterfaceEye2;
@@ -172,19 +175,20 @@ public final class GeneralImageBuilder {
 		if ((leaf.getLeafType() == LeafType.PORT) || (leaf.getLeafType() == LeafType.PORTIN)
 				|| (leaf.getLeafType() == LeafType.PORTOUT)) {
 			final Cluster parent = bibliotekon.getCluster(leaf.getParentContainer());
-			return new EntityImagePort(leaf, skinParam, parent, bibliotekon);
+			return new EntityImagePort(leaf, skinParam, parent, bibliotekon, umlDiagramType.getStyleName());
 		}
 		if (leaf.getLeafType() == LeafType.STATE) {
 			if (leaf.getEntityPosition() != EntityPosition.NORMAL) {
 				final Cluster stateParent = bibliotekon.getCluster(leaf.getParentContainer());
-				return new EntityImageStateBorder(leaf, skinParam, stateParent, bibliotekon);
+				return new EntityImageStateBorder(leaf, skinParam, stateParent, bibliotekon,
+						umlDiagramType.getStyleName());
 			}
 			if (isHideEmptyDescriptionForState && leaf.getBodier().getRawBody().size() == 0) {
 				return new EntityImageStateEmptyDescription(leaf, skinParam);
 			}
 			if (leaf.getStereotype() != null
 					&& "<<sdlreceive>>".equals(leaf.getStereotype().getLabel(Guillemet.DOUBLE_COMPARATOR))) {
-				return new EntityImageState2(leaf, skinParam);
+				return new EntityImageState2(leaf, skinParam, umlDiagramType.getStyleName());
 			}
 			return new EntityImageState(leaf, skinParam);
 
@@ -207,7 +211,7 @@ public final class GeneralImageBuilder {
 			return new EntityImageBranch(leaf, skinParam);
 		}
 		if (leaf.getLeafType() == LeafType.LOLLIPOP_FULL || leaf.getLeafType() == LeafType.LOLLIPOP_HALF) {
-			return new EntityImageLollipopInterface(leaf, skinParam);
+			return new EntityImageLollipopInterface(leaf, skinParam, umlDiagramType.getStyleName());
 		}
 		if (leaf.getLeafType() == LeafType.CIRCLE) {
 			return new EntityImageDescription(leaf, skinParam, portionShower, links, umlDiagramType.getStyleName(),
@@ -239,6 +243,9 @@ public final class GeneralImageBuilder {
 		if (leaf.getLeafType() == LeafType.MAP) {
 			return new EntityImageMap(leaf, skinParam, portionShower);
 		}
+		if (leaf.getLeafType() == LeafType.JSON) {
+			return new EntityImageJson(leaf, skinParam, portionShower);
+		}
 		if (leaf.getLeafType() == LeafType.SYNCHRO_BAR || leaf.getLeafType() == LeafType.STATE_FORK_JOIN) {
 			return new EntityImageSynchroBar(leaf, skinParam, umlDiagramType.getStyleName());
 		}
@@ -261,13 +268,13 @@ public final class GeneralImageBuilder {
 			return new EntityImageEmptyPackage(leaf, skinParam, portionShower, umlDiagramType.getStyleName());
 		}
 		if (leaf.getLeafType() == LeafType.ASSOCIATION) {
-			return new EntityImageAssociation(leaf, skinParam);
+			return new EntityImageAssociation(leaf, skinParam, umlDiagramType.getStyleName());
 		}
 		if (leaf.getLeafType() == LeafType.PSEUDO_STATE) {
-			return new EntityImagePseudoState(leaf, skinParam);
+			return new EntityImagePseudoState(leaf, skinParam, umlDiagramType.getStyleName());
 		}
 		if (leaf.getLeafType() == LeafType.DEEP_HISTORY) {
-			return new EntityImageDeepHistory(leaf, skinParam);
+			return new EntityImageDeepHistory(leaf, skinParam, umlDiagramType.getStyleName());
 		}
 
 		if (leaf.getLeafType() == LeafType.TIPS) {
@@ -299,9 +306,9 @@ public final class GeneralImageBuilder {
 
 	public static UStroke getForcedStroke(Stereotype stereotype, ISkinParam skinParam) {
 		UStroke stroke = skinParam.getThickness(LineParam.packageBorder, stereotype);
-		if (stroke == null) {
+		if (stroke == null)
 			stroke = new UStroke(1.5);
-		}
+
 		return stroke;
 	}
 
@@ -329,17 +336,17 @@ public final class GeneralImageBuilder {
 	}
 
 	final public StyleSignature getDefaultStyleDefinitionArrow(Stereotype stereotype) {
-		StyleSignature result = StyleSignature.of(SName.root, SName.element, styleName, SName.arrow);
-		if (stereotype != null) {
-			result = result.with(stereotype);
-		}
+		StyleSignature result = StyleSignatureBasic.of(SName.root, SName.element, styleName, SName.arrow);
+		if (stereotype != null)
+			result = result.withTOBECHANGED(stereotype);
+
 		return result;
 	}
 
 	private boolean isOpalisable(IEntity entity) {
-		if (strictUmlStyle) {
+		if (strictUmlStyle)
 			return false;
-		}
+
 		return entity.isGroup() == false && entity.getLeafType() == LeafType.NOTE && onlyOneLink(entity);
 	}
 
@@ -391,7 +398,7 @@ public final class GeneralImageBuilder {
 	// Duplicate SvekResult / GeneralImageBuilder
 	private HColor getBackcolor() {
 		if (UseStyle.useBetaStyle()) {
-			final Style style = StyleSignature.of(SName.root, SName.document)
+			final Style style = StyleSignatureBasic.of(SName.root, SName.document)
 					.getMergedStyle(dotData.getSkinParam().getCurrentStyleBuilder());
 			return style.value(PName.BackGroundColor).asColor(dotData.getSkinParam().getThemeStyle(),
 					dotData.getSkinParam().getIHtmlColorSet());
@@ -400,9 +407,9 @@ public final class GeneralImageBuilder {
 	}
 
 	public IEntityImage buildImage(BaseFile basefile, String dotStrings[]) {
-		if (dotData.isDegeneratedWithFewEntities(0)) {
+		if (dotData.isDegeneratedWithFewEntities(0))
 			return new EntityImageSimpleEmpty(dotData.getSkinParam().getBackgroundColor());
-		}
+
 		if (dotData.isDegeneratedWithFewEntities(1) && dotData.getUmlDiagramType() != UmlDiagramType.STATE) {
 			final ILeaf single = dotData.getLeafs().iterator().next();
 			final IGroup group = single.getParentContainer();
@@ -420,9 +427,9 @@ public final class GeneralImageBuilder {
 		printEntities(dotStringFactory, getUnpackagedEntities());
 
 		for (Link link : dotData.getLinks()) {
-			if (link.isRemoved()) {
+			if (link.isRemoved())
 				continue;
-			}
+
 			try {
 				final ISkinParam skinParam = dotData.getSkinParam();
 				final FontConfiguration labelFont = getFontForLink(link, skinParam);
@@ -452,13 +459,11 @@ public final class GeneralImageBuilder {
 			}
 		}
 
-		if (dotStringFactory.illegalDotExe()) {
+		if (dotStringFactory.illegalDotExe())
 			return error(dotStringFactory.getDotExe());
-		}
 
-		if (basefile == null && isSvekTrace()) {
+		if (basefile == null && isSvekTrace())
 			basefile = new BaseFile();
-		}
 
 		final String svg;
 		try {
@@ -466,10 +471,10 @@ public final class GeneralImageBuilder {
 		} catch (IOException e) {
 			return new GraphvizCrash(source.getPlainString(), GraphvizUtils.graphviz244onWindows(), e);
 		}
-		if (svg.length() == 0) {
+		if (svg.length() == 0)
 			return new GraphvizCrash(source.getPlainString(), GraphvizUtils.graphviz244onWindows(),
 					new EmptySvgException());
-		}
+
 		final String graphvizVersion = extractGraphvizVersion(svg);
 		try {
 			dotStringFactory.solve(mergeIntricated, dotData.getEntityFactory(), svg);
@@ -503,24 +508,24 @@ public final class GeneralImageBuilder {
 	private String extractGraphvizVersion(String svg) {
 		final Pattern pGraph = Pattern.compile("(?mi)!-- generated by graphviz(.*)");
 		final Matcher mGraph = pGraph.matcher(svg);
-		if (mGraph.find()) {
+		if (mGraph.find())
 			return StringUtils.trin(mGraph.group(1));
-		}
+
 		return null;
 	}
 
 	private boolean onlyOneLink(IEntity ent) {
 		int nb = 0;
 		for (Link link : dotData.getLinks()) {
-			if (link.isInvis()) {
+			if (link.isInvis())
 				continue;
-			}
-			if (link.contains(ent)) {
+
+			if (link.contains(ent))
 				nb++;
-			}
-			if (nb > 1) {
+
+			if (nb > 1)
 				return false;
-			}
+
 		}
 		return nb == 1;
 	}
@@ -546,17 +551,17 @@ public final class GeneralImageBuilder {
 
 	private void printEntities(DotStringFactory dotStringFactory, Collection<ILeaf> entities2) {
 		for (ILeaf ent : entities2) {
-			if (ent.isRemoved()) {
+			if (ent.isRemoved())
 				continue;
-			}
+
 			printEntity(dotStringFactory, ent);
 		}
 	}
 
 	private void printEntity(DotStringFactory dotStringFactory, ILeaf ent) {
-		if (ent.isRemoved()) {
+		if (ent.isRemoved())
 			throw new IllegalStateException();
-		}
+
 		final IEntityImage image = printEntityInternal(dotStringFactory, ent);
 		final SvekNode node = dotStringFactory.getBibliotekon().createNode(ent, image,
 				dotStringFactory.getColorSequence(), stringBounder);
@@ -564,9 +569,9 @@ public final class GeneralImageBuilder {
 	}
 
 	private IEntityImage printEntityInternal(DotStringFactory dotStringFactory, ILeaf ent) {
-		if (ent.isRemoved()) {
+		if (ent.isRemoved())
 			throw new IllegalStateException();
-		}
+
 		if (ent.getSvekImage() == null) {
 			ISkinParam skinParam = dotData.getSkinParam();
 			if (skinParam.sameClassWidth()) {
@@ -584,35 +589,34 @@ public final class GeneralImageBuilder {
 	private double getMaxWidth(DotStringFactory dotStringFactory) {
 		double result = 0;
 		for (ILeaf ent : dotData.getLeafs()) {
-			if (ent.getLeafType().isLikeClass() == false) {
+			if (ent.getLeafType().isLikeClass() == false)
 				continue;
-			}
+
 			final IEntityImage im = new EntityImageClass(dotStringFactory.getGraphvizVersion(), ent,
 					dotData.getSkinParam(), dotData);
 			final double w = im.calculateDimension(stringBounder).getWidth();
-			if (w > result) {
+			if (w > result)
 				result = w;
-			}
+
 		}
 		return result;
 	}
 
 	private Collection<ILeaf> getUnpackagedEntities() {
 		final List<ILeaf> result = new ArrayList<>();
-		for (ILeaf ent : dotData.getLeafs()) {
-			if (dotData.getTopParent() == ent.getParentContainer()) {
+		for (ILeaf ent : dotData.getLeafs())
+			if (dotData.getTopParent() == ent.getParentContainer())
 				result.add(ent);
-			}
-		}
+
 		return result;
 	}
 
 	private void printGroups(DotStringFactory dotStringFactory, IGroup parent) {
 		final Collection<IGroup> groups = dotData.getGroupHierarchy().getChildrenGroups(parent);
 		for (IGroup g : groups) {
-			if (g.isRemoved()) {
+			if (g.isRemoved())
 				continue;
-			}
+
 			if (dotData.isEmpty(g) && g.getGroupType() == GroupType.PACKAGE) {
 				final ISkinParam skinParam = dotData.getSkinParam();
 				entityFactory.thisIsGoingToBeALeaf(g.getIdent());
@@ -625,9 +629,9 @@ public final class GeneralImageBuilder {
 	}
 
 	private void printGroup(DotStringFactory dotStringFactory, IGroup g) {
-		if (g.getGroupType() == GroupType.CONCURRENT_STATE) {
+		if (g.getGroupType() == GroupType.CONCURRENT_STATE)
 			return;
-		}
+
 		if (mergeIntricated) {
 			final IGroup intricated = dotData.getEntityFactory().isIntricated(g);
 			if (intricated != null) {
@@ -668,23 +672,21 @@ public final class GeneralImageBuilder {
 	public static TextBlock stateHeader(IEntity group, Style style, ISkinParam skinParam) {
 		final List<CharSequence> details = group.getBodier().getRawBody();
 
-		if (details.size() == 0) {
+		if (details.size() == 0)
 			return new TextBlockEmpty();
-		}
+
 		final FontConfiguration fontConfiguration;
-		if (style == null) {
+		if (style == null)
 			fontConfiguration = new FontConfiguration(skinParam, FontParam.STATE_ATTRIBUTE, null);
-		} else {
+		else
 			fontConfiguration = new FontConfiguration(skinParam, style);
-		}
+
 		Display display = null;
-		for (CharSequence s : details) {
-			if (display == null) {
+		for (CharSequence s : details)
+			if (display == null)
 				display = Display.getWithNewlines(s.toString());
-			} else {
+			else
 				display = display.addAll(Display.getWithNewlines(s.toString()));
-			}
-		}
 
 		return display.create(fontConfiguration, HorizontalAlignment.LEFT, skinParam);
 
@@ -697,17 +699,25 @@ public final class GeneralImageBuilder {
 
 	private TextBlock getTitleBlock(IGroup g) {
 		final Display label = g.getDisplay();
-		if (label == null) {
+		if (label == null)
 			return TextBlockUtils.empty(0, 0);
-		}
+
 		final ISkinParam skinParam = dotData.getSkinParam();
 		final FontConfiguration fontConfiguration;
 		if (UseStyle.useBetaStyle()) {
 			final SName sname = dotData.getUmlDiagramType().getStyleName();
-			final Style style = StyleSignature.of(SName.root, SName.element, sname, SName.title) //
-					.with(g.getStereotype()) //
+			final StyleSignatureBasic signature;
+			final USymbol uSymbol = g.getUSymbol();
+			if (uSymbol == USymbols.RECTANGLE)
+				signature = StyleSignatureBasic.of(SName.root, SName.element, sname, uSymbol.getSName(), SName.title);
+			else
+				signature = StyleSignatureBasic.of(SName.root, SName.element, sname, SName.title);
+
+			final Style style = signature //
+					.withTOBECHANGED(g.getStereotype()) //
 					.with(g.getStereostyles()) //
 					.getMergedStyle(skinParam.getCurrentStyleBuilder());
+
 			fontConfiguration = style.getFontConfiguration(skinParam.getThemeStyle(), skinParam.getIHtmlColorSet());
 		} else
 			fontConfiguration = g.getFontConfigurationForTitle(skinParam);
@@ -716,9 +726,9 @@ public final class GeneralImageBuilder {
 	}
 
 	private TextBlock addLegend(TextBlock original, DisplayPositioned legend) {
-		if (legend == null || legend.isNull()) {
+		if (legend == null || legend.isNull())
 			return original;
-		}
+
 		final TextBlock legendBlock = EntityImageLegend.create(legend.getDisplay(), dotData.getSkinParam());
 		return DecorateEntityImage.add(legendBlock, original, legend.getHorizontalAlignment(),
 				legend.getVerticalAlignment());
@@ -732,39 +742,48 @@ public final class GeneralImageBuilder {
 	private TextBlock getStereoBlockWithoutLegend(IGroup g) {
 		final Stereotype stereotype = g.getStereotype();
 		// final DisplayPositionned legend = g.getLegend();
-		if (stereotype == null) {
+		if (stereotype == null)
 			return TextBlockUtils.empty(0, 0);
-		}
+
 		final TextBlock tmp = stereotype.getSprite(dotData.getSkinParam());
-		if (tmp != null) {
+		if (tmp != null)
 			return tmp;
-		}
 
 		final List<String> stereos = stereotype.getLabels(dotData.getSkinParam().guillemet());
-		if (stereos == null) {
+		if (stereos == null)
 			return TextBlockUtils.empty(0, 0);
-		}
-		final boolean show = dotData.showPortion(EntityPortion.STEREOTYPE, g);
-		if (show == false) {
-			return TextBlockUtils.empty(0, 0);
-		}
 
+		final boolean show = dotData.showPortion(EntityPortion.STEREOTYPE, g);
+		if (show == false)
+			return TextBlockUtils.empty(0, 0);
+
+		if (UseStyle.useBetaStyle()) {
+			final Style style = Cluster
+					.getDefaultStyleDefinition(dotData.getUmlDiagramType().getStyleName(), g.getUSymbol())
+					.forStereotypeItself(g.getStereotype())
+					.getMergedStyle(dotData.getSkinParam().getCurrentStyleBuilder());
+
+			final FontConfiguration fontConfiguration = style.getFontConfiguration(
+					dotData.getSkinParam().getThemeStyle(), dotData.getSkinParam().getIHtmlColorSet());
+			return Display.create(stereos).create(fontConfiguration, HorizontalAlignment.CENTER,
+					dotData.getSkinParam());
+		}
 		final FontParam fontParam = FontParam.PACKAGE_STEREOTYPE;
 		return Display.create(stereos).create(new FontConfiguration(dotData.getSkinParam(), fontParam, stereotype),
 				HorizontalAlignment.CENTER, dotData.getSkinParam());
 	}
 
 	public String getWarningOrError(int warningOrError) {
-		if (maxX == null) {
+		if (maxX == null)
 			return "";
-		}
+
 		final StringBuilder sb = new StringBuilder();
-		for (Map.Entry<String, Double> ent : maxX.entrySet()) {
+		for (Map.Entry<String, Double> ent : maxX.entrySet())
 			if (ent.getValue() > warningOrError) {
 				sb.append(ent.getKey() + " is overpassing the width limit.");
 				sb.append("\n");
 			}
-		}
+
 		return sb.length() == 0 ? "" : sb.toString();
 	}
 }
