@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -66,7 +66,7 @@ import net.sourceforge.plantuml.skin.rose.Rose;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.style.StyleSignature;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.image.EntityImageState;
 import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
@@ -92,9 +92,9 @@ public final class GroupPngMakerState {
 		}
 
 		public Collection<IGroup> getChildrenGroups(IGroup parent) {
-			if (EntityUtils.groupRoot(parent)) {
+			if (EntityUtils.groupRoot(parent))
 				return diagram.getChildrenGroups(group);
-			}
+
 			return diagram.getChildrenGroups(parent);
 		}
 
@@ -108,28 +108,27 @@ public final class GroupPngMakerState {
 		this.diagram = diagram;
 		this.stringBounder = stringBounder;
 		this.group = group;
-		if (group.isGroup() == false) {
+		if (group.isGroup() == false)
 			throw new IllegalArgumentException();
-		}
+
 	}
 
 	private List<Link> getPureInnerLinks() {
 		final List<Link> result = new ArrayList<>();
-		for (Link link : diagram.getLinks()) {
-			if (EntityUtils.isPureInnerLink12(group, link)) {
+		for (Link link : diagram.getLinks())
+			if (EntityUtils.isPureInnerLink12(group, link))
 				result.add(link);
-			}
-		}
+
 		return result;
 	}
 
 	private Style getStyleStateHeader() {
-		return StyleSignature.of(SName.root, SName.element, SName.stateDiagram, SName.state, SName.header)
-				.with(group.getStereotype()).getMergedStyle(diagram.getSkinParam().getCurrentStyleBuilder());
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.stateDiagram, SName.state, SName.header)
+				.withTOBECHANGED(group.getStereotype()).getMergedStyle(diagram.getSkinParam().getCurrentStyleBuilder());
 	}
 
 	private Style getStyleState() {
-		return StyleSignature.of(SName.root, SName.element, SName.stateDiagram, SName.state).with(group.getStereotype())
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.stateDiagram, SName.state).withTOBECHANGED(group.getStereotype())
 				.getMergedStyle(diagram.getSkinParam().getCurrentStyleBuilder());
 	}
 
@@ -155,9 +154,9 @@ public final class GroupPngMakerState {
 
 		final TextBlock title = display.create(fontConfiguration, HorizontalAlignment.CENTER, diagram.getSkinParam());
 
-		if (group.size() == 0 && group.getChildren().size() == 0) {
+		if (group.size() == 0 && group.getChildren().size() == 0)
 			return new EntityImageState(group, diagram.getSkinParam());
-		}
+
 		final List<Link> links = getPureInnerLinks();
 
 		final DotData dotData = new DotData(group, links, group.getLeafsDirect(), diagram.getUmlDiagramType(),
@@ -168,37 +167,39 @@ public final class GroupPngMakerState {
 		final GeneralImageBuilder svek2 = new GeneralImageBuilder(false, dotData, diagram.getEntityFactory(),
 				diagram.getSource(), diagram.getPragma(), stringBounder, SName.stateDiagram);
 
-		if (group.getGroupType() == GroupType.CONCURRENT_STATE) {
-			// return new InnerStateConcurrent(svek2.createFile());
+		if (group.getGroupType() == GroupType.CONCURRENT_STATE)
 			return svek2.buildImage(null, new String[0]);
-		}
 
-		if (group.getGroupType() != GroupType.STATE) {
+		if (group.getGroupType() != GroupType.STATE)
 			throw new UnsupportedOperationException(group.getGroupType().toString());
-		}
 
 		HColor borderColor = group.getColors().getColor(ColorType.LINE);
-		if (borderColor == null) {
+		if (borderColor == null)
 			if (UseStyle.useBetaStyle())
 				borderColor = getStyleState().value(PName.LineColor).asColor(skinParam.getThemeStyle(),
 						skinParam.getIHtmlColorSet());
 			else
 				borderColor = getColor(ColorParam.stateBorder, group.getStereotype());
-		}
+
 		final Stereotype stereo = group.getStereotype();
 		final HColor tmp = group.getColors().getColor(ColorType.BACK);
 		final HColor backColor;
 		if (tmp == null)
 			if (UseStyle.useBetaStyle())
-				backColor =
-
-						getStyleState().value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
-								skinParam.getIHtmlColorSet());
+				backColor = getStyleState().value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
+						skinParam.getIHtmlColorSet());
 			else
 				backColor = getColor(ColorParam.stateBackground, stereo);
 		else
 			backColor = tmp;
 
+		UStroke stroke = group.getColors().getSpecificLineStroke();
+		if (stroke == null)
+			if (UseStyle.useBetaStyle())
+				stroke = getStyleState().getStroke();
+			else
+				stroke = new UStroke(1.5);
+
 		final TextBlock attribute = GeneralImageBuilder.stateHeader((IEntity) group, null, skinParam);
 
 		final Stereotype stereotype = group.getStereotype();
@@ -207,10 +208,7 @@ public final class GroupPngMakerState {
 		final boolean containsOnlyConcurrentStates = containsOnlyConcurrentStates(dotData);
 		final IEntityImage image = containsOnlyConcurrentStates ? buildImageForConcurrentState(dotData)
 				: svek2.buildImage(null, new String[0]);
-		UStroke stroke = group.getColors().getSpecificLineStroke();
-		if (stroke == null) {
-			stroke = new UStroke(1.5);
-		}
+
 		return new InnerStateAutonom(image, title, attribute, borderColor, backColor, group.getUrl99(), withSymbol,
 				stroke, rounded, shadowing);
 
@@ -218,9 +216,9 @@ public final class GroupPngMakerState {
 
 	private IEntityImage buildImageForConcurrentState(DotData dotData) {
 		final List<IEntityImage> inners = new ArrayList<>();
-		for (ILeaf inner : dotData.getLeafs()) {
+		for (ILeaf inner : dotData.getLeafs())
 			inners.add(inner.getSvekImage());
-		}
+
 		return new CucaDiagramFileMakerSvek2InternalImage(inners, dotData.getTopParent().getConcurrentSeparator(),
 				dotData.getSkinParam(), group.getStereotype());
 
@@ -228,12 +226,12 @@ public final class GroupPngMakerState {
 
 	private boolean containsOnlyConcurrentStates(DotData dotData) {
 		for (ILeaf leaf : dotData.getLeafs()) {
-			if (leaf instanceof IGroup == false) {
+			if (leaf instanceof IGroup == false)
 				return false;
-			}
-			if (((IGroup) leaf).getLeafType() != LeafType.STATE_CONCURRENT) {
+
+			if (((IGroup) leaf).getLeafType() != LeafType.STATE_CONCURRENT)
 				return false;
-			}
+
 		}
 		return true;
 	}
