@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
- * 
+ *
  * If you like this project or if you find it useful, you can support us at:
- * 
+ *
  * http://plantuml.com/patreon (only 1$ per month!)
  * http://plantuml.com/paypal
- * 
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,12 +30,12 @@
  *
  *
  * Original Author:  Arnaud Roques
- * 
+ *
  *
  */
 package net.sourceforge.plantuml.svg;
 
-import java.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.awt.geom.PathIterator;
 import java.awt.image.BufferedImage;
 import java.io.ByteArrayOutputStream;
@@ -109,10 +109,12 @@ public class SvgGraphics {
 	final private Element gRoot;
 
 	private String fill = "black";
-	private String fillDark = "black";
-	private Collection<String> classesForDarkness = new LinkedHashSet<>();
 	private String stroke = "black";
-	private String strokeDark = "black";
+
+//	private Collection<String> classesForDarkness = new LinkedHashSet<>();
+//	private String strokeDark = "black";
+//	private String fillDark = "black";
+
 	private String strokeWidth;
 	private String strokeDasharray = null;
 	private final String backcolor;
@@ -129,7 +131,7 @@ public class SvgGraphics {
 	private final boolean svgDimensionStyle;
 	private final LengthAdjust lengthAdjust;
 
-	private final boolean INTERACTIVE = false;
+	private final boolean interactive;
 
 	final protected void ensureVisible(double x, double y) {
 		if (x > maxX) {
@@ -141,7 +143,8 @@ public class SvgGraphics {
 	}
 
 	public SvgGraphics(String backcolor, boolean svgDimensionStyle, Dimension2D minDim, double scale, String hover,
-			long seed, String preserveAspectRatio, LengthAdjust lengthAdjust) {
+			long seed, String preserveAspectRatio, LengthAdjust lengthAdjust, DarkStrategy darkStrategy,
+			boolean interactive) {
 		try {
 			this.lengthAdjust = lengthAdjust;
 			this.svgDimensionStyle = svgDimensionStyle;
@@ -149,6 +152,7 @@ public class SvgGraphics {
 			this.document = getDocument();
 			this.backcolor = backcolor;
 			this.preserveAspectRatio = preserveAspectRatio;
+			this.interactive = interactive;
 			ensureVisible(minDim.getWidth(), minDim.getHeight());
 
 			this.root = getRootNode();
@@ -164,7 +168,7 @@ public class SvgGraphics {
 			if (hover != null)
 				defs.appendChild(getPathHover(hover));
 
-			if (INTERACTIVE) {
+			if (interactive) {
 				final Element styles = getStylesForInteractiveMode();
 				if (styles != null)
 					defs.appendChild(styles);
@@ -191,33 +195,33 @@ public class SvgGraphics {
 		return style;
 	}
 
-	private Element getStylesForDarkness() {
-		final Element style = simpleElement("style");
-		final StringBuilder text1 = new StringBuilder();
-		final StringBuilder text2 = new StringBuilder("@media (prefers-color-scheme:dark) {");
-		final Pattern p = Pattern.compile("^(\\w)_(\\w+)_(\\w+)$");
-		for (String s : this.classesForDarkness) {
-			final Matcher m = p.matcher(s);
-			if (m.matches() == false)
-				throw new IllegalStateException();
-			final String color1 = m.group(2);
-			final String color2 = m.group(3);
-			final String type = m.group(1);
-			if ("f".equals(type)) {
-				text1.append("*." + s + " {fill:#" + color1 + ";}");
-				text2.append("*." + s + " {fill:#" + color2 + ";}");
-			} else if ("s".equals(type)) {
-				text1.append("*." + s + " {stroke:#" + color1 + ";}");
-				text2.append("*." + s + " {stroke:#" + color2 + ";}");
-			} else
-				throw new IllegalStateException();
-		}
-		text2.append("}");
-		final CDATASection cdata = document.createCDATASection(text1.toString() + text2.toString());
-		style.setAttribute("type", "text/css");
-		style.appendChild(cdata);
-		return style;
-	}
+//	private Element getStylesForDarkness() {
+//		final Element style = simpleElement("style");
+//		final StringBuilder text1 = new StringBuilder();
+//		final StringBuilder text2 = new StringBuilder("@media (prefers-color-scheme:dark) {");
+//		final Pattern p = Pattern.compile("^(\\w)_(\\w+)_(\\w+)$");
+//		for (String s : this.classesForDarkness) {
+//			final Matcher m = p.matcher(s);
+//			if (m.matches() == false)
+//				throw new IllegalStateException();
+//			final String color1 = m.group(2);
+//			final String color2 = m.group(3);
+//			final String type = m.group(1);
+//			if ("f".equals(type)) {
+//				text1.append("*." + s + " {fill:#" + color1 + ";}");
+//				text2.append("*." + s + " {fill:#" + color2 + ";}");
+//			} else if ("s".equals(type)) {
+//				text1.append("*." + s + " {stroke:#" + color1 + ";}");
+//				text2.append("*." + s + " {stroke:#" + color2 + ";}");
+//			} else
+//				throw new IllegalStateException();
+//		}
+//		text2.append("}");
+//		final CDATASection cdata = document.createCDATASection(text1.toString() + text2.toString());
+//		style.setAttribute("type", "text/css");
+//		style.appendChild(cdata);
+//		return style;
+//	}
 
 	private Element getScriptForInteractiveMode() {
 		final Element script = document.createElement("script");
@@ -375,22 +379,22 @@ public class SvgGraphics {
 
 	public final void setFillColor(String fill) {
 		this.fill = fill == null ? "none" : fill;
-		this.fillDark = this.fill;
+		// this.fillDark = this.fill;
 	}
 
 	public final void setFillColor(String fill, String fillDark) {
 		this.fill = fill == null ? "none" : fill;
-		this.fillDark = fillDark == null ? "none" : fillDark;
+		// this.fillDark = fillDark == null ? "none" : fillDark;
 	}
 
 	public final void setStrokeColor(String stroke) {
 		this.stroke = stroke == null ? "none" : stroke;
-		this.strokeDark = stroke;
+		// this.strokeDark = stroke;
 	}
 
 	public final void setStrokeColor(String stroke, String strokeDark) {
 		this.stroke = stroke == null ? "none" : stroke;
-		this.strokeDark = strokeDark == null ? "none" : strokeDark;
+		// this.strokeDark = strokeDark == null ? "none" : strokeDark;
 	}
 
 	public final void setStrokeWidth(double strokeWidth, String strokeDasharray) {
@@ -446,13 +450,13 @@ public class SvgGraphics {
 	}
 
 	private void manageDarkStroke(final Element elt) {
-		if (strokeDark != null && stroke.equals(strokeDark) == false) {
-			final String attribute = elt.getAttribute("class");
-			if (attribute == null || attribute.length() == 0)
-				elt.setAttribute("class", getStrokeClassForDark());
-			else
-				elt.setAttribute("class", attribute + " " + getStrokeClassForDark());
-		}
+//		if (strokeDark != null && stroke.equals(strokeDark) == false) {
+//			final String attribute = elt.getAttribute("class");
+//			if (attribute == null || attribute.length() == 0)
+//				elt.setAttribute("class", getStrokeClassForDark());
+//			else
+//				elt.setAttribute("class", attribute + " " + getStrokeClassForDark());
+//		}
 	}
 
 	public void svgLine(double x1, double y1, double x2, double y2, double deltaShadow) {
@@ -474,8 +478,8 @@ public class SvgGraphics {
 
 	private String getStyle() {
 		final StringBuilder style = new StringBuilder();
-		if (stroke.equals(strokeDark))
-			style.append("stroke:" + stroke + ";");
+		// if (stroke.equals(strokeDark))
+		style.append("stroke:" + stroke + ";");
 		style.append("stroke-width:" + strokeWidth + ";");
 		if (fill.equals("#00000000"))
 			style.append("fill:none;");
@@ -489,8 +493,8 @@ public class SvgGraphics {
 	// https://forum.plantuml.net/12469/package-background-transparent-package-default-background?show=12479#c12479
 	private String getStyleSpecial() {
 		final StringBuilder style = new StringBuilder();
-		if (stroke.equals(strokeDark))
-			style.append("stroke:" + stroke + ";");
+		// if (stroke.equals(strokeDark))
+		style.append("stroke:" + stroke + ";");
 		style.append("stroke-width:" + strokeWidth + ";");
 		if (fill.equals("#00000000"))
 			style.append("fill:none;");
@@ -659,8 +663,8 @@ public class SvgGraphics {
 	}
 
 	private void createXmlInternal(OutputStream os) throws TransformerException {
-		if (this.classesForDarkness.size() > 0)
-			defs.appendChild(getStylesForDarkness());
+//		if (this.classesForDarkness.size() > 0)
+//			defs.appendChild(getStylesForDarkness());
 
 		// Get a DOMSource object that represents the
 		// Document object
@@ -669,7 +673,7 @@ public class SvgGraphics {
 		final int maxXscaled = (int) (maxX * scale);
 		final int maxYscaled = (int) (maxY * scale);
 		String style = "width:" + maxXscaled + "px;height:" + maxYscaled + "px;";
-		if (backcolor != null)
+		if (/*this.classesForDarkness.size() == 0 &&*/ backcolor != null)
 			style += "background:" + backcolor + ";";
 
 		if (svgDimensionStyle) {
@@ -680,7 +684,7 @@ public class SvgGraphics {
 		root.setAttribute("viewBox", "0 0 " + maxXscaled + " " + maxYscaled);
 		root.setAttribute("zoomAndPan", "magnify");
 		root.setAttribute("preserveAspectRatio", preserveAspectRatio);
-		root.setAttribute("contentScriptType", "application/ecmascript");
+		// root.setAttribute("contentScriptType", "application/ecmascript");
 		root.setAttribute("contentStyleType", "text/css");
 
 		if (pendingBackground != null) {
@@ -736,8 +740,8 @@ public class SvgGraphics {
 			final Element elt = (Element) document.createElement("path");
 			elt.setAttribute("d", sb.toString());
 			elt.setAttribute("style", getStyle());
-			manageDarkStroke(elt);
 			fillMe(elt);
+			manageDarkStroke(elt);
 			final String id = path.getComment();
 			if (id != null)
 				elt.setAttribute("id", id);
@@ -751,28 +755,31 @@ public class SvgGraphics {
 		}
 	}
 
-	private String getFillClassForDark() {
-		final String result = "f_" + fill.toLowerCase().replaceAll("\\#", "") + "_"
-				+ fillDark.toLowerCase().replaceAll("\\#", "");
-		this.classesForDarkness.add(result);
-		return result;
-	}
-
-	private String getStrokeClassForDark() {
-		final String result = "s_" + stroke.toLowerCase().replaceAll("\\#", "") + "_"
-				+ strokeDark.toLowerCase().replaceAll("\\#", "");
-		this.classesForDarkness.add(result);
-		return result;
-	}
+//	private String getFillClassForDark() {
+//		final String result = "f_" + fill.toLowerCase().replaceAll("\\#", "") + "_"
+//				+ fillDark.toLowerCase().replaceAll("\\#", "");
+//		this.classesForDarkness.add(result);
+//		return result;
+//	}
+//
+//	private String getStrokeClassForDark() {
+//		final String result = "s_" + stroke.toLowerCase().replaceAll("\\#", "") + "_"
+//				+ strokeDark.toLowerCase().replaceAll("\\#", "");
+//		this.classesForDarkness.add(result);
+//		return result;
+//	}
 
 	private void fillMe(Element elt) {
 		if (fill.equals("#00000000"))
 			return;
 
-		if (fill.equals(fillDark) == false) {
-			elt.setAttribute("class", getFillClassForDark());
-			return;
-		}
+//		if (fill.equals(fillDark) == false) {
+//			if (elt.getAttribute("class") != null && elt.getAttribute("class").length() != 0)
+//				throw new IllegalStateException();
+//
+//			elt.setAttribute("class", getFillClassForDark());
+//			return;
+//		}
 
 		if (fill.matches("#[0-9A-Fa-f]{8}")) {
 			elt.setAttribute("fill", fill.substring(0, 7));
@@ -983,6 +990,31 @@ public class SvgGraphics {
 		getG().appendChild(commentElement);
 	}
 
+	public void addScriptTag(String url) {
+		final Element script = document.createElement("script");
+		script.setAttribute("type", "text/javascript");
+		script.setAttribute("xlink:href", url);
+		root.appendChild(script);
+	}
+
+	public void addScript(String scriptTextPath) {
+		final Element script = document.createElement("script");
+		final String scriptText = getData(scriptTextPath);
+		final CDATASection cDATAScript = document.createCDATASection(scriptText);
+		script.appendChild(cDATAScript);
+		root.appendChild(script);
+	}
+
+	public void addStyle(String cssStylePath) {
+		final Element style = simpleElement("style");
+		final String text = getData(cssStylePath);
+
+		final CDATASection cdata = document.createCDATASection(text);
+		style.setAttribute("type", "text/css");
+		style.appendChild(cdata);
+		root.appendChild(style);
+	}
+
 	public void openLink(String url, String title, String target) {
 		Objects.requireNonNull(url);
 
@@ -990,8 +1022,8 @@ public class SvgGraphics {
 		if (SecurityUtils.ignoreThisLink(url))
 			return;
 
-		if (pendingAction.size() > 0)
-			closeLink();
+//		if (pendingAction.size() > 0)
+//			closeLink();
 
 		pendingAction.add(0, (Element) document.createElement("a"));
 		pendingAction.get(0).setAttribute("target", target);
@@ -1036,13 +1068,17 @@ public class SvgGraphics {
 		}
 	}
 
-	public void startGroup(UGroupType type, String ident) {
-		if (type == UGroupType.ID) {
-			pendingAction.add(0, (Element) document.createElement("g"));
-			pendingAction.get(0).setAttribute("id", ident);
-		} else if (INTERACTIVE && type == UGroupType.CLASS) {
-			pendingAction.add(0, (Element) document.createElement("g"));
-			pendingAction.get(0).setAttribute("class", ident);
+	public void startGroup(Map<UGroupType, String> typeIdents) {
+		if (typeIdents.isEmpty())
+			throw new IllegalArgumentException();
+
+		pendingAction.add(0, (Element) document.createElement("g"));
+
+		for (Map.Entry<UGroupType, String> typeIdent : typeIdents.entrySet()) {
+			if (typeIdent.getKey() == UGroupType.ID)
+				pendingAction.get(0).setAttribute("id", typeIdent.getValue());
+			if (interactive && typeIdent.getKey() == UGroupType.CLASS)
+				pendingAction.get(0).setAttribute("class", typeIdent.getValue());
 		}
 	}
 
