@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,7 +35,6 @@
  */
 package net.sourceforge.plantuml.syntax;
 
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 
@@ -45,10 +44,10 @@ import net.sourceforge.plantuml.ErrorUml;
 import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.LineLocationImpl;
 import net.sourceforge.plantuml.OptionFlags;
-import net.sourceforge.plantuml.PSystemError;
 import net.sourceforge.plantuml.SourceStringReader;
 import net.sourceforge.plantuml.UmlDiagram;
 import net.sourceforge.plantuml.core.Diagram;
+import net.sourceforge.plantuml.error.PSystemError;
 import net.sourceforge.plantuml.preproc.Defines;
 
 public class SyntaxChecker {
@@ -68,18 +67,14 @@ public class SyntaxChecker {
 
 		if (source.startsWith("@startuml\n") == false) {
 			result.setError(true);
-			result.setLineLocation(new LineLocationImpl(null, null).oneLineRead());
-			// result.setErrorLinePosition(0);
-			result.addErrorText("No @startuml found");
-			// result.setSuggest(Arrays.asList("Did you mean:", "@startuml"));
+			result.setLineLocation(new LineLocationImpl("", null).oneLineRead());
+			result.addErrorText("No @startuml/@enduml found");
 			return result;
 		}
 		if (source.endsWith("@enduml\n") == false && source.endsWith("@enduml") == false) {
 			result.setError(true);
 			result.setLineLocation(lastLineNumber2(source));
-			// result.setErrorLinePosition(lastLineNumber(source));
 			result.addErrorText("No @enduml found");
-			// result.setSuggest(Arrays.asList("Did you mean:", "@enduml"));
 			return result;
 		}
 		final SourceStringReader sourceStringReader = new SourceStringReader(Defines.createEmpty(), source,
@@ -89,9 +84,7 @@ public class SyntaxChecker {
 		if (blocks.size() == 0) {
 			result.setError(true);
 			result.setLineLocation(lastLineNumber2(source));
-			// result.setErrorLinePosition(lastLineNumber(source));
 			result.addErrorText("No @enduml found");
-			// result.setSuggest(Arrays.asList("Did you mean:", "@enduml"));
 			return result;
 		}
 		final Diagram system = blocks.get(0).getDiagram();
@@ -102,13 +95,11 @@ public class SyntaxChecker {
 		} else if (system instanceof PSystemError) {
 			result.setError(true);
 			final PSystemError sys = (PSystemError) system;
-			// result.setErrorLinePosition(sys.getHigherErrorPosition());
 			result.setLineLocation(sys.getLineLocation());
 			result.setSystemError(sys);
 			for (ErrorUml er : sys.getErrorsUml()) {
 				result.addErrorText(er.getError());
 			}
-			// result.setSuggest(sys.getSuggest());
 		} else {
 			result.setDescription(system.getDescription().getDescription());
 		}
@@ -125,7 +116,6 @@ public class SyntaxChecker {
 			result.setError(true);
 			result.setLineLocation(lastLineNumber2(source));
 			result.addErrorText("No @enduml found");
-			// result.setSuggest(Arrays.asList("Did you mean:", "@enduml"));
 			return result;
 		}
 
@@ -137,13 +127,11 @@ public class SyntaxChecker {
 		} else if (system instanceof PSystemError) {
 			result.setError(true);
 			final PSystemError sys = (PSystemError) system;
-			// result.setErrorLinePosition(sys.getHigherErrorPosition());
 			result.setLineLocation(sys.getLineLocation());
 			for (ErrorUml er : sys.getErrorsUml()) {
 				result.addErrorText(er.getError());
 			}
 			result.setSystemError(sys);
-			// result.setSuggest(sys.getSuggest());
 		} else {
 			result.setDescription(system.getDescription().getDescription());
 		}
@@ -161,7 +149,7 @@ public class SyntaxChecker {
 	}
 
 	private static LineLocation lastLineNumber2(String source) {
-		LineLocationImpl result = new LineLocationImpl(null, null).oneLineRead();
+		LineLocationImpl result = new LineLocationImpl("", null).oneLineRead();
 		for (int i = 0; i < source.length(); i++) {
 			if (source.charAt(i) == '\n') {
 				result = result.oneLineRead();
