@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
- * 
+ *
  * If you like this project or if you find it useful, you can support us at:
- * 
+ *
  * http://plantuml.com/patreon (only 1$ per month!)
  * http://plantuml.com/paypal
- * 
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,7 +30,7 @@
  *
  *
  * Original Author:  Arnaud Roques
- * 
+ *
  *
  */
 package net.sourceforge.plantuml.ugraphic;
@@ -42,6 +42,7 @@ import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 import java.io.IOException;
 import java.io.OutputStream;
+import java.util.Map;
 
 public interface UGraphic {
 
@@ -59,7 +60,7 @@ public interface UGraphic {
 
 	public void closeUrl();
 
-	public void startGroup(UGroupType type, String ident);
+	public void startGroup(Map<UGroupType, String> typeIdents);
 
 	public void closeGroup();
 
