@@ -12,7 +12,7 @@
  * This file is part of Smetana.
  * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * This translation is distributed under the same Licence as the original C program.
  * 
@@ -36,11 +36,11 @@
 
 package smetana.core;
 
-import h.*;
-
-public interface CFunction extends __ptr__, Dtmemory_f, Dtcompar_f, Dtsearch_f {
+public interface CFunction extends __ptr__ {
 	
 	public Object exe(Object... args);
 
+	public String getName();
+
 
 }
